@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -39,6 +39,8 @@
 #include "displayer_clist_config.h"
 #include "displayer_clist_config_dlg.h"
 
+#include "displayer_clist_status.h"
+
 static GtkWidget *displayer_clist_win = NULL;
 static GtkWidget
 		*displayer_clist_vbox,
@@ -52,11 +54,11 @@ static GtkTooltips
 extern SingitConfigGen *displayer_clist_config;
 
 void displayer_clist_init(void);
-void displayer_clist_show(void);
-void displayer_clist_hide(void);
-void displayer_clist_toggle(void);
+void displayer_clist_show(SingitSong *cur_song);
+void displayer_clist_hide(SingitSong *cur_song);
+void displayer_clist_toggle(SingitSong *cur_song);
 void displayer_clist_finish(void);
-void displayer_clist_set_time(guint time, LSong *cur_song, GList *real_next);
+void displayer_clist_set_time(guint time, SingitSong *cur_song, GList *real_next);
 void displayer_clist_config_update(const SingitConfigData *singit_config);
 void displayer_clist_configure(void);
 
@@ -87,47 +89,20 @@ DisplayerPlugin clist_dp =
 	NULL
 };
 
-DisplayerPlugin *get_dplugin_info(void)
-{
-	clist_dp.description = g_strdup("Navigation displayer");
-	return &clist_dp;
-}
+DIPSPLAYER_SYMBOL(libdisplayer_clist, clist_dp)
 
-// Changed by program - not restored
-typedef struct _CListStatus {
-
-	gint lastRow;
-	gint line;
-	gint jump_to_song;
-
-	guint timestamp_context_id;
-	guint song_context_id;
-	guint messageCounter;
-
-	GList *next_lyric_line;
-	LSong *song;
-
-	gboolean print_debug;
-	gboolean auto_resize;
-	gboolean show_empty;
-	gboolean toggle_yz;
-
-	gint win_size_y;
-
-} CListStatus;
-
-CListStatus displayer_clist_status =
-	{ -1, -1, 0, 0, 0, 0, NULL, NULL, FALSE, TRUE, FALSE, FALSE, -1 };
+void displayer_clist_config_update_event(SingitConfigGen *scg, CListConfigData *cfg_data, gpointer user_data);
 
 static void displayer_clist_clst_jumpToTime(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data)
 {
 	GList *item = NULL;
 	gboolean isPlaying, doReturn = FALSE;
-	LSong *cur_song = NULL;
-	if ((!event) || (!displayer_clist_win) ||
-		((cur_song = l_song_attach(displayer_clist_status.song)) == NULL)) { return; }
+	SingitSong *cur_song = NULL;
 
-	// Prevent to show the focus row
+	if ((!event) || (!displayer_clist_win) ||
+		((cur_song = singit_song_attach(displayer_clist_status.song)) == NULL)) { return; }
+
+// Prevent to show the focus row
 	if (GTK_CLIST(clist)->focus_row != -1) {
 		GTK_CLIST(clist)->focus_row = -1;
 		if (GTK_CLIST(clist)->freeze_count == 0)
@@ -138,9 +113,9 @@ static void displayer_clist_clst_jumpToTime(GtkWidget *clist, gint row, gint col
 
 	if (!isPlaying && cur_song) {
 		if (!doReturn) { doReturn = (cur_song->active_token == NULL); }
-		if (!doReturn) { doReturn = (tLine(cur_song->active_token) == row); }
+		if (!doReturn) { doReturn = ((gint) tLine(cur_song->active_token) == row); }
 		if (doReturn) {
-			l_song_detach(cur_song, TRUE);
+			singit_song_detach(&cur_song);
 			return;
 		}
 	}
@@ -152,15 +127,18 @@ static void displayer_clist_clst_jumpToTime(GtkWidget *clist, gint row, gint col
 	if (displayer_clist_status.lastRow == row) {
 		item = cur_song->first_token;
 		while (item != cur_song->last_token) {
-			if (tLine(item) == row) {
+			if ((gint) tLine(item) == row) {
 				if (!isPlaying) { xmms_remote_play(clist_dp.xmms_session); }
 				xmms_remote_jump_to_time(clist_dp.xmms_session, tTime(item));
-				l_song_detach(cur_song, TRUE);
+				singit_song_detach(&cur_song);
+#				ifdef CODEDEBUG
+				DEBUG(("Ok\n"));
+#				endif
 				return;
 			}
 			item = g_list_next(item);
 		}
-		if (tLine(item) == row) {
+		if ((gint) tLine(item) == row) {
 			if (!isPlaying) { xmms_remote_play(clist_dp.xmms_session); }
 			xmms_remote_jump_to_time(clist_dp.xmms_session, tTime(item));
 		}
@@ -168,7 +146,9 @@ static void displayer_clist_clst_jumpToTime(GtkWidget *clist, gint row, gint col
 	else {
 		displayer_clist_status.lastRow = row;
 	}
-	l_song_detach(cur_song, TRUE);
+
+	singit_song_detach(&cur_song);
+
 #	ifdef CODEDEBUG
         DEBUG(("Ok\n"));
 #	endif
@@ -209,68 +189,69 @@ static void set_statusbar_messages(gint time)
 	}
 }
 
-
 static void lyrics_not_found(void)
 {
 	gchar *fileNotFound, *nlbr[1][1];
 	gint width, height;
 
+#	ifdef CODEDEBUG
+	DEBUG(("displayer_clist.c [lyrics_not_found]\n"));
+#	endif
+
 	gtk_clist_freeze(GTK_CLIST(displayer_clist_clst));
 	gtk_clist_clear(GTK_CLIST(displayer_clist_clst));
 	fileNotFound = g_strconcat(_("Lyrics not found"), NULL);
 	nlbr[0][0] = fileNotFound;
 	gtk_clist_append(GTK_CLIST(displayer_clist_clst), nlbr[0]);
-	if (displayer_clist_status.auto_resize) {
+	if (GET_CFG(displayer_clist_config,autoResize) == TRUE) {
 		gdk_window_get_size (displayer_clist_win->window, &width, &height);
 		gtk_window_set_default_size(GTK_WINDOW(displayer_clist_win), 230, 80);
 	}
 	g_free(fileNotFound);
 	gtk_clist_thaw(GTK_CLIST(displayer_clist_clst));
 
-	if (displayer_clist_status.timestamp_context_id != 0) { set_statusbar_messages(0); }
+	if (displayer_clist_status.timestamp_context_id != 0)
+		{ set_statusbar_messages(0); }
 }
 
-static void update_clist(LSong *new_song)
+static void update_clist(SingitSong *new_song)
 {
-        gchar *tmp, *lbr[1][1];
-        gint i = 0, strlength = -1;
-	LSong *my_song = NULL;
-	gint maxLineWidth = 0;
+        gchar *lbr[2];
+        gint i = 0;
+	SingitSong *my_song = NULL;
+	gint clist_width;
 
 #	ifdef CODEDEBUG
-	DEBUG(("displayer_clist.c [build_clist] : "));
+	DEBUG(("displayer_clist.c [update_clist]\n"));
 #	endif
 
 	gtk_clist_freeze(GTK_CLIST(displayer_clist_clst));
 	gtk_clist_clear(GTK_CLIST(displayer_clist_clst));
-	my_song = l_song_attach(new_song);
-	if (my_song) {
-		if (displayer_clist_status.timestamp_context_id != 0) { set_statusbar_messages(0); }
 
+	my_song = singit_song_attach(new_song);
+	if (my_song) {
+		if (displayer_clist_status.timestamp_context_id != 0)
+			{ set_statusbar_messages(0); }
+
+		// * Fill the clist *
+		lbr[1] = NULL;
 		i = 0;
 		while (my_song->lyrics[i]) {
-			strlength = strlen(&my_song->lyrics[i][0]);
-			if (strlength > 0) { tmp = g_strndup(&my_song->lyrics[i][0], strlength); }
-			else { tmp = strdup("\0"); }
-			lbr[0][0] = tmp;
-			gtk_clist_append(GTK_CLIST(displayer_clist_clst), lbr[0]);
-			if (strlength > 0) {
-		  		strlength = gdk_string_width(gtk_widget_get_style(displayer_clist_clst)->font, tmp);
-		  		if (strlength > maxLineWidth) { maxLineWidth = strlength; }
-			}
-			g_free(tmp);
+			lbr[0] = my_song->lyrics[i];
+			gtk_clist_append(GTK_CLIST(displayer_clist_clst), lbr);
 			i++;
 		}
 
-		#ifdef CODEDEBUG
-		DEBUG((" Most length line: %i\n", maxLineWidth));
-		#endif
-		if (maxLineWidth < 150) { maxLineWidth = 150; }
-		if (displayer_clist_status.auto_resize) {
+		// * Resize the clist *
+		if (GET_CFG(displayer_clist_config,autoResize) == TRUE) {
+			clist_width = gtk_clist_columns_autosize
+				(GTK_CLIST(displayer_clist_clst));
+			if (clist_width < 150) { clist_width = 150; }
 			gtk_window_set_default_size(GTK_WINDOW(displayer_clist_win),
-				maxLineWidth + 45, displayer_clist_status.win_size_y);
+				clist_width + 45,
+				displayer_clist_status.win_size_y);
 		}
-		l_song_detach(my_song, TRUE);
+		singit_song_detach(&my_song);
 	}
 	gtk_clist_thaw(GTK_CLIST(displayer_clist_clst));
 }
@@ -280,20 +261,24 @@ static void set_status_filename(gchar *fileName)
 	gchar *tmp;
 	if (!displayer_clist_win) { return; }
 	if (displayer_clist_status.song_context_id) {
-		gtk_statusbar_pop(GTK_STATUSBAR(displayer_clist_song_status_bar), displayer_clist_status.song_context_id);
+		gtk_statusbar_pop(GTK_STATUSBAR
+			(displayer_clist_song_status_bar),
+			displayer_clist_status.song_context_id);
 	}
 	else {
 		displayer_clist_status.song_context_id =
-			gtk_statusbar_get_context_id(GTK_STATUSBAR(displayer_clist_song_status_bar), "filename");
+			gtk_statusbar_get_context_id(GTK_STATUSBAR
+				(displayer_clist_song_status_bar), "filename");
 	}
 	tmp = g_strconcat(" ", fileName, NULL);
 	gtk_statusbar_push(GTK_STATUSBAR(displayer_clist_song_status_bar),
 		displayer_clist_status.song_context_id, tmp);
-	gtk_tooltips_set_tip(displayer_clist_tooltips, displayer_clist_song_gtk_event_box, fileName, NULL);
+	gtk_tooltips_set_tip(displayer_clist_tooltips,
+		displayer_clist_song_gtk_event_box, fileName, NULL);
 	g_free(tmp);
 }
 
-void select_item(gint new_item, gboolean show)
+static void select_item(gint new_item, gboolean show)
 {
 	if (displayer_clist_status.line > -1)
 		gtk_clist_unselect_row(GTK_CLIST(displayer_clist_clst),
@@ -306,10 +291,10 @@ void select_item(gint new_item, gboolean show)
 	displayer_clist_status.line = new_item;
 }
 
-void displayer_clist_set_time(guint time, LSong *cur_song, GList *real_next)
+void displayer_clist_set_time(guint time, SingitSong *cur_song, GList *real_next)
 {
 	GList *item = NULL;
-	LSong* my_song = NULL, *tmp_song;
+	SingitSong* my_song = NULL, *tmp_song;
 	gboolean update_song = FALSE;
 	gboolean update_selection = FALSE;
 	gboolean update_timer = FALSE;
@@ -317,8 +302,11 @@ void displayer_clist_set_time(guint time, LSong *cur_song, GList *real_next)
 	gint new_item = -1;
 	gint timer;
 
-	if (displayer_clist_win && GTK_WIDGET_VISIBLE(displayer_clist_win)) {
-		my_song = l_song_attach(cur_song);
+	if (displayer_clist_win && GTK_WIDGET_VISIBLE(displayer_clist_win) &&
+		(gdk_window_is_visible(displayer_clist_win->window)) &&
+		(gdk_window_is_viewable(displayer_clist_win->window)))
+	{
+		my_song = singit_song_attach(cur_song);
 		if (!my_song) { return; }
 
 		if ((my_song != displayer_clist_status.song) ||
@@ -326,27 +314,29 @@ void displayer_clist_set_time(guint time, LSong *cur_song, GList *real_next)
 		{
 			displayer_clist_status.line = -1;
 			tmp_song = displayer_clist_status.song;
-			displayer_clist_status.song = l_song_attach(my_song);
-			l_song_detach(tmp_song, TRUE);
+			displayer_clist_status.song = singit_song_attach(my_song);
+			singit_song_detach(&tmp_song);
 			update_song = TRUE;
 		}
 
-		if (l_song_text_found(my_song)) {
-			// Has the active token and ???
-			if (l_song_lyrics_found(my_song)) {
-				new_item = tLine(my_song->active_token);
-				if (displayer_clist_status.line != new_item)
-				{
-					if (!l_song_is_empty_item(my_song, my_song->active_token)
-						|| displayer_clist_status.show_empty)
+		if (singit_song_text_found(my_song)) {
+			// * Has the active token and ??? *
+			if (singit_song_lyrics_found(my_song)) {
+				if (my_song->active_token != NULL) {
+					new_item = tLine(my_song->active_token);
+					if (displayer_clist_status.line != new_item)
 					{
-						show_item = TRUE;
-					}
+						if (!singit_song_is_empty_item(my_song, my_song->active_token, FALSE)
+							|| (GET_CFG(displayer_clist_config,showEmpty) == TRUE))
+						{
+							show_item = TRUE;
+						}
 
-					update_selection = TRUE;
+						update_selection = TRUE;
+					}
 				}
 
-				// Has the timer status changed ???
+				// * Has the timer status changed ??? *
 				item = (real_next) ? real_next : my_song->last_token;
 				if (item != NULL) {
 					timer = (time / 1000);
@@ -358,20 +348,21 @@ void displayer_clist_set_time(guint time, LSong *cur_song, GList *real_next)
 				}
 			}
 
-			// Any updates needed ???
+			// * Any updates needed ??? *
 			if (update_song || update_selection || update_timer) {
-				// Obtain GDK lock
+
 				GDK_THREADS_ENTER();
 
-				// Run any updates
+				// * Run any updates *
 				if (update_song) {
 					set_status_filename(my_song->song_filename);
 					update_clist(my_song);
 				}
-				if (update_selection) { select_item(new_item, show_item); }
-				if (update_timer) { set_statusbar_messages(tTime(item) - time); }
+				if (update_selection)
+					{ select_item(new_item, show_item); }
+				if (update_timer)
+					{ set_statusbar_messages(tTime(item) - time); }
 
-				// Release GDK lock
 				GDK_THREADS_LEAVE();
 			}
 		}
@@ -380,7 +371,7 @@ void displayer_clist_set_time(guint time, LSong *cur_song, GList *real_next)
 			lyrics_not_found();
 			GDK_THREADS_LEAVE();
 		}
-		l_song_detach(my_song, TRUE);
+		singit_song_detach(&my_song);
 	}
 }
 
@@ -405,11 +396,9 @@ static gboolean displayer_clist_win_keypress(GtkWidget * w, GdkEventKey * event,
 		case GDK_e:
 			if (event->state & GDK_CONTROL_MASK) { singit_editor_show(); }
 			break;
-#		ifdef HAVE_ID3
 		case GDK_i:
-			if (event->state & GDK_CONTROL_MASK) { singit_id3dlg_show(); }
+			if (event->state & GDK_CONTROL_MASK) { singit_tag_manager_show(); }
 			break;
-#		endif
 		case GDK_p:
 			if (event->state & GDK_CONTROL_MASK) { singit_config_show(); }
 			break;
@@ -420,11 +409,11 @@ static gboolean displayer_clist_win_keypress(GtkWidget * w, GdkEventKey * event,
                         xmms_remote_play(clist_dp.xmms_session);
                         break;
 		case GDK_y:
-			if (displayer_clist_status.toggle_yz)
+			if (GET_DCC(displayer_clist_config)->gblToggleYZ)
 				{ xmms_remote_playlist_prev(clist_dp.xmms_session); }
 			break;
                 case GDK_z:
-			if (!displayer_clist_status.toggle_yz)
+			if (!GET_DCC(displayer_clist_config)->gblToggleYZ)
 				{ xmms_remote_playlist_prev(clist_dp.xmms_session); }
                         break;
 		case GDK_KP_Add:
@@ -481,59 +470,54 @@ static gboolean displayer_clist_win_keypress(GtkWidget * w, GdkEventKey * event,
 			}
 			break;
                 default:
-			// printf("%x - %x\n", event->state, event->keyval);
                         break;
         }
 
         return TRUE;
 }
 
-void displayer_clist_resize_event (GtkWidget *widget, gpointer user_data)
+static void displayer_clist_resize_event (GtkWidget *widget, gpointer user_data)
 {
 	gint width, height;
-	LSong *cur_song = NULL;
+	SingitSong *cur_song = NULL;
 
 	if (!displayer_clist_win) { return; }
-	cur_song = l_song_attach(displayer_clist_status.song);
+	cur_song = singit_song_attach(displayer_clist_status.song);
 	if (!cur_song) { return; }
-	if (l_song_lyrics_found(cur_song) && displayer_clist_win->window)
-		if (displayer_clist_status.auto_resize) {
+	if (singit_song_lyrics_found(cur_song) && displayer_clist_win->window)
+		if (GET_CFG(displayer_clist_config,autoResize) == TRUE) {
 			gdk_window_get_size (displayer_clist_win->window, &width, &height);
 			displayer_clist_status.win_size_y = height;
 		}
 	if (displayer_clist_clst)
 		if (cur_song->active_token)
 			gtk_clist_moveto(GTK_CLIST(displayer_clist_clst), tLine(cur_song->active_token), -1, 0.5, 0);
-	l_song_detach(cur_song, TRUE);
+	singit_song_detach(&cur_song);
 }
 
 void displayer_clist_finish(void)
 {
-	gint posX, posY;
+	CListConfigData *ccd;
 
 #	ifdef CODEDEBUG
 	DEBUG(("displayer_clist.c [displayer_clist_finish]\n"));
 #	endif
 
 	if (displayer_clist_win) {
-//		if (displayer_clist_status.timestamp_context_id != 0) { set_statusbar_messages(0); }
-		if (displayer_clist_win->window) {
-			gdk_window_get_root_origin(displayer_clist_win->window, &posX, &posY);
-			singit_config_save_plugin_position("clist_navigator", posX, posY, -1, -1);
+		ccd = GET_DCC(displayer_clist_config);
+		if (displayer_clist_win->window && (ccd != NULL)) {
+			gdk_window_get_root_origin(displayer_clist_win->window, &ccd->winPosX, &ccd->winPosY);
+			singit_config_gen_save(SINGIT_CONFIG_GEN(displayer_clist_config));
 		}
 		gtk_widget_destroy(displayer_clist_win);
-
-		displayer_clist_status.messageCounter = 0;
-		displayer_clist_status.timestamp_context_id = 0;
 	}
 
-	displayer_clist_status.lastRow = -1;
-	displayer_clist_status.line = 0;
+	singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_clist_config));
 
-	displayer_clist_status.song = l_song_detach(displayer_clist_status.song, TRUE);
+	displayer_clist_status_finish();
 }
 
-gint displayer_clist_delete_event(GtkWidget *widget, GdkEvent  *event, gpointer data)
+static gint displayer_clist_delete_event(GtkWidget *widget, GdkEvent  *event, gpointer data)
 {
 	clist_dp.disable(&clist_dp);
 	return (FALSE);
@@ -542,30 +526,30 @@ gint displayer_clist_delete_event(GtkWidget *widget, GdkEvent  *event, gpointer
 void displayer_clist_init(void)
 {
 	gchar* title;
-	gint posX, posY;
 	CListConfigData *ccd;
 
 #	ifdef CODEDEBUG
 	DEBUG(("dlg_singit_navigator.c [displayer_clist_init]\n"));
 #	endif
 
-	if (displayer_clist_win) { return; }
+	g_return_if_fail(displayer_clist_win == NULL);
+
+	displayer_clist_status_init();
 
 	if (!singit_config_gen_attach(displayer_clist_config)) {
 		displayer_clist_config = displayer_clist_config_new();
 		singit_config_gen_load(SINGIT_CONFIG_GEN(displayer_clist_config));
 	}
 
-	if (!singit_config_gen_attach(SINGIT_CONFIG_GEN(displayer_clist_config))) {
-		displayer_clist_config = displayer_clist_config_new();
-		singit_config_gen_load(SINGIT_CONFIG_GEN(displayer_clist_config));
-	}
-	ccd = getDCC(displayer_clist_config);
+	ccd = GET_DCC(displayer_clist_config);
 	if (!ccd) {
 		singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_clist_config));
 		return;
 	}
 
+	gtk_signal_connect(GTK_OBJECT(displayer_clist_config), "update",
+		GTK_SIGNAL_FUNC(displayer_clist_config_update_event), NULL);
+
 	displayer_clist_tooltips = gtk_tooltips_new ();
 
 	displayer_clist_win = gtk_window_new(GTK_WINDOW_DIALOG);
@@ -574,10 +558,14 @@ void displayer_clist_init(void)
 	g_free(title);
 	gtk_window_set_policy(GTK_WINDOW(displayer_clist_win), TRUE, TRUE, TRUE);
 	gtk_widget_set_usize(displayer_clist_win, 180, 200);
-	gtk_signal_connect(GTK_OBJECT(displayer_clist_win), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &displayer_clist_win);
-	gtk_signal_connect(GTK_OBJECT(displayer_clist_win), "delete_event", GTK_SIGNAL_FUNC(displayer_clist_delete_event), NULL);
-	gtk_signal_connect(GTK_OBJECT(displayer_clist_win), "key-press-event", GTK_SIGNAL_FUNC(displayer_clist_win_keypress), NULL);
-	gtk_signal_connect(GTK_OBJECT(displayer_clist_win), "size-allocate", GTK_SIGNAL_FUNC(displayer_clist_resize_event), NULL);
+	gtk_signal_connect(GTK_OBJECT(displayer_clist_win),
+		"destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &displayer_clist_win);
+	gtk_signal_connect(GTK_OBJECT(displayer_clist_win),
+		"delete_event", GTK_SIGNAL_FUNC(displayer_clist_delete_event), NULL);
+	gtk_signal_connect(GTK_OBJECT(displayer_clist_win),
+		"key-press-event", GTK_SIGNAL_FUNC(displayer_clist_win_keypress), NULL);
+	gtk_signal_connect(GTK_OBJECT(displayer_clist_win),
+		"size-allocate", GTK_SIGNAL_FUNC(displayer_clist_resize_event), NULL);
 	gtk_container_border_width(GTK_CONTAINER(displayer_clist_win), 5);
 
 	displayer_clist_vbox = gtk_vbox_new(FALSE, 0);
@@ -590,8 +578,8 @@ void displayer_clist_init(void)
 	gtk_widget_show (displayer_clist_scrlwnd);
 
 	displayer_clist_clst = gtk_clist_new(1);
-	gtk_signal_connect(GTK_OBJECT(displayer_clist_clst), "select_row",
-		GTK_SIGNAL_FUNC(displayer_clist_clst_jumpToTime), NULL);
+	gtk_signal_connect(GTK_OBJECT(displayer_clist_clst),
+		"select_row", GTK_SIGNAL_FUNC(displayer_clist_clst_jumpToTime), NULL);
 	gtk_clist_set_selection_mode(GTK_CLIST(displayer_clist_clst), GTK_SELECTION_SINGLE);
 	gtk_clist_set_reorderable (GTK_CLIST(displayer_clist_clst), FALSE);
 	gtk_container_add(GTK_CONTAINER(displayer_clist_scrlwnd), displayer_clist_clst);
@@ -603,21 +591,25 @@ void displayer_clist_init(void)
 	gtk_widget_show(displayer_clist_hbox);
 
 	displayer_clist_timestamp_status_bar = gtk_statusbar_new();
-	gtk_box_pack_start (GTK_BOX(displayer_clist_hbox), displayer_clist_timestamp_status_bar, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX(displayer_clist_hbox),
+		displayer_clist_timestamp_status_bar, FALSE, FALSE, 0);
 	gtk_widget_show(displayer_clist_timestamp_status_bar);
 
 	displayer_clist_song_gtk_event_box = gtk_event_box_new ();
-	gtk_container_add (GTK_CONTAINER(displayer_clist_hbox), displayer_clist_song_gtk_event_box);
+	gtk_container_add (GTK_CONTAINER(displayer_clist_hbox),
+		displayer_clist_song_gtk_event_box);
 	gtk_widget_show (displayer_clist_song_gtk_event_box);
 
 	displayer_clist_song_status_bar = gtk_statusbar_new();
-	gtk_container_add (GTK_CONTAINER (displayer_clist_song_gtk_event_box), displayer_clist_song_status_bar);
+	gtk_container_add (GTK_CONTAINER (displayer_clist_song_gtk_event_box),
+		displayer_clist_song_status_bar);
 	gtk_widget_show(displayer_clist_song_status_bar);
 
-	gtk_object_set_data (GTK_OBJECT (displayer_clist_win), "tooltips", displayer_clist_tooltips);
+	gtk_object_set_data (GTK_OBJECT (displayer_clist_win),
+		"tooltips", displayer_clist_tooltips);
 
-	/* Normally a window is created when it's shown first, so if not shown
-	we must explicit realize it to get a GDK_WINDOW */
+// * Normally a window is created when it's shown first, so if not shown *
+// * we must explicit realize it to get a GDK_WINDOW *
 	gtk_widget_realize(displayer_clist_win);
 
 	displayer_clist_status.song_context_id =
@@ -628,14 +620,16 @@ void displayer_clist_init(void)
 	gtk_statusbar_push(GTK_STATUSBAR(displayer_clist_timestamp_status_bar),
 		displayer_clist_status.timestamp_context_id, "         ");
 
-	if (singit_config_load_plugin_position("clist_navigator", &posX, &posY, NULL, NULL))
-		gdk_window_move(displayer_clist_win->window, posX, posY);
+	if ((ccd->winPosX >= 0) && (ccd->winPosY >= 0))
+		gdk_window_move(displayer_clist_win->window, ccd->winPosX, ccd->winPosY);
 	else
 		gtk_window_set_position
 			(GTK_WINDOW(displayer_clist_win), GTK_WIN_POS_CENTER);
+
+	displayer_clist_config_update_event(NULL, ccd, NULL);
 }
 
-void displayer_clist_show(void)
+void displayer_clist_show(SingitSong *cur_song)
 {
 #	ifdef CODEDEBUG
 	DEBUG(("displayer_clist.c [displayer_clist_show]\n"));
@@ -648,26 +642,30 @@ void displayer_clist_show(void)
 	}
 }
 
-void displayer_clist_hide(void)
+void displayer_clist_hide(SingitSong *cur_song)
 {
+	gboolean hide_it = TRUE;
+
 #	ifdef CODEDEBUG
 	DEBUG(("displayer_clist.c [displayer_clist_hide]\n"));
 #	endif
 
-	if (displayer_clist_win) {
-		if (GTK_WIDGET_VISIBLE(displayer_clist_win) &&
-			(!(displayer_clist_config && getDCC(displayer_clist_config)->showOnText &&
-			 displayer_clist_status.song &&
-			 l_song_text_found(displayer_clist_status.song))
-			)
-		)
-		{
-			gtk_widget_hide(displayer_clist_win);
+	if (displayer_clist_config != NULL) {
+		hide_it = GET_CFG(displayer_clist_config, hideIfNotFound);
+		if ((hide_it == TRUE) && (GET_DCC(displayer_clist_config)->showOnText == TRUE)) {
+			if (cur_song != NULL) {
+				hide_it = (singit_song_text_found(cur_song) == FALSE);
+			}
 		}
 	}
+
+	if (displayer_clist_win) {
+		if (GTK_WIDGET_VISIBLE(displayer_clist_win) && hide_it)
+			{ gtk_widget_hide(displayer_clist_win); }
+	}
 }
 
-void displayer_clist_toggle(void)
+void displayer_clist_toggle(SingitSong *cur_song)
 {
 #	ifdef CODEDEBUG
 	DEBUG(("displayer_clist.c [displayer_clist_toggle]\n"));
@@ -682,10 +680,12 @@ void displayer_clist_toggle(void)
 
 void displayer_clist_config_update(const SingitConfigData *singit_config)
 {
-	displayer_clist_status.auto_resize = singit_config->autoResize;
-	displayer_clist_status.print_debug = singit_config->debugEnable;
-	displayer_clist_status.show_empty = singit_config->showEmpty;
-	displayer_clist_status.toggle_yz = singit_config->toggleYZ;
+	CListConfigData *ccd = GET_DCC(displayer_clist_config);
+
+	ccd->gblToggleYZ = singit_config->toggleYZ;
+
+	if (ccd->forceGlobals == TRUE)
+		{ displayer_clist_config_update_event(displayer_clist_config, ccd, NULL); }
 }
 
 void displayer_clist_configure(void)
@@ -696,3 +696,76 @@ void displayer_clist_configure(void)
 
 	displayer_clist_config_show();
 }
+
+void displayer_clist_config_update_event(SingitConfigGen *scg, CListConfigData *cfg_data, gpointer user_data)
+{
+#	define REAL_CFG(val) \
+		((cfg_data->forceGlobals == TRUE) ? GET_SCD->val : cfg_data->val)
+
+	GtkRcStyle *rc_style;
+	GdkFont *newFont;
+	gchar *font_name;
+	GtkCList *clist;
+
+#	ifdef CODEDEBUG
+	DEBUG(("displayer_clist.c [displayer_clist_config_update_event]\n"));
+#	endif
+
+	if (displayer_clist_win == NULL) { return; }
+
+	if ((cfg_data->forceGlobals == TRUE) && GET_SCD) {
+		cfg_data->autoResize = GET_SCD->autoResize;
+		cfg_data->debugEnable = GET_SCD->debugEnable;
+		cfg_data->showEmpty = GET_SCD->showEmpty;
+	}
+
+	clist = GTK_CLIST(displayer_clist_clst);
+	rc_style = gtk_rc_style_new ();
+
+	gtk_clist_freeze(clist);
+
+// * Check if we could load a font with this name
+	font_name = REAL_CFG(lyricFontName);
+	if ((newFont = gdk_font_load(font_name)) != NULL) {
+		gdk_font_unref(newFont);
+		rc_style->font_name = g_strdup(font_name);
+		rc_style->fontset_name = g_strdup(font_name);
+	}
+
+	/* Ok - is there any logic to use these colors ??? */
+
+// color of a selected row
+	gdk_color_parse(REAL_CFG(progressBarColor), &rc_style->bg[GTK_STATE_SELECTED]);
+	rc_style->color_flags[GTK_STATE_SELECTED] |= GTK_RC_BG;
+
+// color of the normal text
+	gdk_color_parse(REAL_CFG(normalTextColor), &rc_style->fg[GTK_STATE_NORMAL]);
+	rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_FG;
+
+// color of the a selected row text
+	gdk_color_parse(REAL_CFG(progressTextColor), &rc_style->fg[GTK_STATE_SELECTED]);
+	rc_style->color_flags[GTK_STATE_SELECTED] |= GTK_RC_FG;
+
+// background color of the row
+	gdk_color_parse(REAL_CFG(normalBarColor), &rc_style->base[GTK_STATE_NORMAL]);
+	rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_BASE;
+
+// "background" color of the space between the rows
+	gdk_color_parse(REAL_CFG(backgroundColor), &rc_style->base[GTK_STATE_ACTIVE]);
+	rc_style->color_flags[GTK_STATE_ACTIVE] |= GTK_RC_BASE;
+
+	gtk_widget_modify_style(displayer_clist_clst, rc_style);
+
+	gtk_rc_style_unref(rc_style);
+
+// * Reseize the window *
+	if (REAL_CFG(autoResize) == TRUE) {
+		gtk_window_set_default_size(GTK_WINDOW(displayer_clist_win),
+			gtk_clist_columns_autosize(clist) + 45,
+			displayer_clist_status.win_size_y);
+	}
+
+	gtk_clist_thaw(clist);
+
+#	undef REAL_CFG
+}
