@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,16 +34,17 @@
 
 #include "singit_config_gen.h"
 #include "displayer_clist_config.h"
+#include "displayer_clist_config_dlg.h"
 
 #include "singit_wgt_colorbutton.h"
 
 static GtkWidget *displayer_clist_config_win = NULL;
 static GtkWidget
 	*displayer_clist_config_vbox,
+		*displayer_clist_config_force_globals_frame,
+			*displayer_clist_config_force_globals_check_button,
 		*displayer_clist_config_notebook,
 		*displayer_clist_config_displayer_vbox, *displayer_clist_config_displayer_label,
-			*displayer_clist_config_force_globals_frame,
-				*displayer_clist_config_force_globals_check_button,
 			*displayer_clist_config_font_frame,
 				*displayer_clist_config_font_hbox,
 				*displayer_clist_config_font_entry,
@@ -51,19 +52,23 @@ static GtkWidget
 				*displayer_clist_config_fontsel,
 			*displayer_clist_config_color_frame,
 				*displayer_clist_config_color_vbox,
-				*displayer_clist_config_color_active_hbox_widget,
-				*displayer_clist_config_color_active_label,
-				*displayer_clist_config_color_active_button,
 				*displayer_clist_config_color_background_hbox_widget,
 				*displayer_clist_config_color_background_label,
 				*displayer_clist_config_color_background_button,
-				*displayer_clist_config_color_text_hbox_widget,
-				*displayer_clist_config_color_text_label,
-				*displayer_clist_config_color_text_button,
+				*displayer_clist_config_color_normal_text_hbox_widget,
+				*displayer_clist_config_color_normal_text_label,
+				*displayer_clist_config_color_normal_text_button,
+				*displayer_clist_config_color_normal_bar_hbox_widget,
+				*displayer_clist_config_color_normal_bar_label,
+				*displayer_clist_config_color_normal_bar_button,
+				*displayer_clist_config_color_progress_text_hbox_widget,
+				*displayer_clist_config_color_progress_text_label,
+				*displayer_clist_config_color_progress_text_button,
+				*displayer_clist_config_color_progress_bar_hbox_widget,
+				*displayer_clist_config_color_progress_bar_label,
+				*displayer_clist_config_color_progress_bar_button,
 		*displayer_clist_config_displayer_toggle_vbox, *displayer_clist_config_displayer_toggle_label,
 			*displayer_clist_config_hide_if_not_found_check_button,
-			*displayer_clist_config_show_ball_check_button,
-			*displayer_clist_config_guess_sync_lyrics_check_button,
 			*displayer_clist_config_show_empty_check_button,
 			*displayer_clist_config_auto_resize_check_button,
 #ifdef CODEDEBUG
@@ -84,7 +89,7 @@ static GtkTooltips
 typedef struct {
 
 	guchar *color_array;
-	guint exporter_selection;
+//	guint exporter_selection;
 
 	gboolean updating_displayer_list;
 
@@ -93,21 +98,25 @@ typedef struct {
 ConfigStatus displayer_clist_config_status;
 extern SingitConfigGen *displayer_clist_config;
 
-void displayer_clist_config_font_browse_ok(GtkWidget * w, gpointer data)
+static void displayer_clist_config_font_browse_ok(GtkWidget * w, gpointer data)
 {
         gtk_entry_set_text(GTK_ENTRY(displayer_clist_config_font_entry),
 		gtk_font_selection_dialog_get_font_name(GTK_FONT_SELECTION_DIALOG(displayer_clist_config_fontsel)));
         gtk_widget_destroy(displayer_clist_config_fontsel);
 }
 
-void displayer_clist_config_font_browse_cb(GtkWidget * w, gpointer data)
+static void displayer_clist_config_font_browse_cb(GtkWidget * w, gpointer data)
 {
+	gchar *temp;
+
         if (!displayer_clist_config_fontsel)
         {
-                displayer_clist_config_fontsel = gtk_font_selection_dialog_new(_("Select lyric font:"));
+		temp = g_strconcat(_("Select lyric font"), ":", NULL);
+                displayer_clist_config_fontsel = gtk_font_selection_dialog_new(temp);
+		g_free(temp);
 		gtk_window_set_modal(GTK_WINDOW(displayer_clist_config_fontsel), TRUE);
                 gtk_font_selection_dialog_set_font_name(GTK_FONT_SELECTION_DIALOG(displayer_clist_config_fontsel),
-			getDCC(displayer_clist_config)->lyricFontName);
+			GET_DCC(displayer_clist_config)->lyricFontName);
                 gtk_signal_connect(GTK_OBJECT(GTK_FONT_SELECTION_DIALOG(displayer_clist_config_fontsel)->ok_button), "clicked",
 			GTK_SIGNAL_FUNC(displayer_clist_config_font_browse_ok), NULL);
                 gtk_signal_connect_object(GTK_OBJECT(GTK_FONT_SELECTION_DIALOG(displayer_clist_config_fontsel)->cancel_button),
@@ -118,18 +127,20 @@ void displayer_clist_config_font_browse_cb(GtkWidget * w, gpointer data)
         }
 }
 
-void displayer_clist_config_force_globals_toggle_event(GtkToggleButton *toggleButton,  gpointer data)
+static void displayer_clist_config_force_globals_toggle_event(GtkToggleButton *toggleButton,  gpointer data)
 {
 	gboolean state = !gtk_toggle_button_get_active(toggleButton);
 
 	gtk_widget_set_sensitive(displayer_clist_config_font_entry, state);
 	gtk_widget_set_sensitive(displayer_clist_config_font_browse_button, state);
-	gtk_widget_set_sensitive(displayer_clist_config_color_active_button, state);
+
 	gtk_widget_set_sensitive(displayer_clist_config_color_background_button, state);
-	gtk_widget_set_sensitive(displayer_clist_config_color_text_button, state);
+	gtk_widget_set_sensitive(displayer_clist_config_color_normal_text_button, state);
+	gtk_widget_set_sensitive(displayer_clist_config_color_normal_bar_button, state);
+	gtk_widget_set_sensitive(displayer_clist_config_color_progress_text_button, state);
+	gtk_widget_set_sensitive(displayer_clist_config_color_progress_bar_button, state);
+
 	gtk_widget_set_sensitive(displayer_clist_config_hide_if_not_found_check_button, state);
-	gtk_widget_set_sensitive(displayer_clist_config_show_ball_check_button, state);
-	gtk_widget_set_sensitive(displayer_clist_config_guess_sync_lyrics_check_button, state);
 	gtk_widget_set_sensitive(displayer_clist_config_show_empty_check_button, state);
 	gtk_widget_set_sensitive(displayer_clist_config_auto_resize_check_button, state);
 #	ifdef CODEDEBUG
@@ -139,7 +150,7 @@ void displayer_clist_config_force_globals_toggle_event(GtkToggleButton *toggleBu
 
 static void displayer_clist_config_cleanup()
 {
-	CListConfigData *ccd = getDCC(displayer_clist_config);
+	CListConfigData *ccd = GET_DCC(displayer_clist_config);
 
 #	ifdef CODEDEBUG
 	DEBUG(("dlg_singit_config.c [displayer_clist_config_cleanup]\n"));
@@ -156,10 +167,10 @@ static void displayer_clist_config_cleanup()
 	singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_clist_config));
 }
 
-void displayer_clist_config_apply_clicked(GtkButton *button, gpointer user_data)
+static void displayer_clist_config_apply_clicked(GtkButton *button, gpointer user_data)
 {
 	gchar tmp[13];
-	CListConfigData *ccd = getDCC(displayer_clist_config);
+	CListConfigData *ccd = GET_DCC(displayer_clist_config);
 
 #	ifdef CODEDEBUG
 	DEBUG(("dlg_singit_config.c [displayer_clist_config_apply_clicked] : "));
@@ -178,36 +189,41 @@ void displayer_clist_config_apply_clicked(GtkButton *button, gpointer user_data)
 	tmp[12] = '\0';
 
 	g_free(ccd->lyricFontName);
-	g_free(ccd->activeColor);
 	g_free(ccd->backgroundColor);
-	g_free(ccd->textColor);
+	g_free(ccd->normalTextColor);
+	g_free(ccd->normalBarColor);
+	g_free(ccd->progressTextColor);
+	g_free(ccd->progressBarColor);
 
 	/* set new values */
 
+	ccd->forceGlobals = GTK_TOGGLE_BUTTON(displayer_clist_config_force_globals_check_button)->active;
+
 	ccd->lyricFontName = gtk_editable_get_chars(GTK_EDITABLE(displayer_clist_config_font_entry), 0, -1);
 	ccd->showEmpty = GTK_TOGGLE_BUTTON(displayer_clist_config_show_empty_check_button)->active;
 	ccd->autoResize = GTK_TOGGLE_BUTTON(displayer_clist_config_auto_resize_check_button)->active;
 	ccd->hideIfNotFound = GTK_TOGGLE_BUTTON(displayer_clist_config_hide_if_not_found_check_button)->active;
-	ccd->showJumpingBall = GTK_TOGGLE_BUTTON(displayer_clist_config_show_ball_check_button)->active;
-	ccd->guessSyncLyrics = GTK_TOGGLE_BUTTON(displayer_clist_config_guess_sync_lyrics_check_button)->active;
 	ccd->showOnText = GTK_TOGGLE_BUTTON(displayer_clist_config_show_on_text_check_button)->active;
 
 #	ifdef CODEDEBUG
 	ccd->debugEnable = GTK_TOGGLE_BUTTON(displayer_clist_config_enable_debug_check_button)->active;
 #	endif
 
-	sprintf(tmp, "rgb:%.2x/%.2x/%.2x", (gushort) ((guchar *) (COLOR_BUTTON(displayer_clist_config_color_active_button)->color))[0],
-		(gushort) ((guchar *) (COLOR_BUTTON(displayer_clist_config_color_active_button)->color))[1],
-		(gushort) ((guchar *) (COLOR_BUTTON(displayer_clist_config_color_active_button)->color))[2]);
-	ccd->activeColor = g_strdup(tmp);
-	sprintf(tmp, "rgb:%.2x/%.2x/%.2x", (gushort) ((guchar *) (COLOR_BUTTON(displayer_clist_config_color_background_button)->color))[0],
-		(gushort) ((guchar *) (COLOR_BUTTON(displayer_clist_config_color_background_button)->color))[1],
-		(gushort) ((guchar *) (COLOR_BUTTON(displayer_clist_config_color_background_button)->color))[2]);
-	ccd->backgroundColor = g_strdup(tmp);
-	sprintf(tmp, "rgb:%.2x/%.2x/%.2x", (gushort) ((guchar *) (COLOR_BUTTON(displayer_clist_config_color_text_button)->color))[0],
-		(gushort) ((guchar *) (COLOR_BUTTON(displayer_clist_config_color_text_button)->color))[1],
-		(gushort) ((guchar *) (COLOR_BUTTON(displayer_clist_config_color_text_button)->color))[2]);
-	ccd->textColor = g_strdup(tmp);
+#define GET_RGB_AS_STRING(a,b) { sprintf(tmp, "rgb:%.2x/%.2x/%.2x", \
+		(gushort) ((guchar *) (COLOR_BUTTON(a)->color))[0], \
+		(gushort) ((guchar *) (COLOR_BUTTON(a)->color))[1], \
+		(gushort) ((guchar *) (COLOR_BUTTON(a)->color))[2]); \
+		b = g_strdup(tmp); }
+
+	GET_RGB_AS_STRING(displayer_clist_config_color_background_button, ccd->backgroundColor);
+	GET_RGB_AS_STRING(displayer_clist_config_color_normal_text_button, ccd->normalTextColor);
+	GET_RGB_AS_STRING(displayer_clist_config_color_normal_bar_button, ccd->normalBarColor);
+	GET_RGB_AS_STRING(displayer_clist_config_color_progress_text_button, ccd->progressTextColor);
+	GET_RGB_AS_STRING(displayer_clist_config_color_progress_bar_button, ccd->progressBarColor);
+
+#undef GET_RGB_AS_STRING
+
+	ccd->lyricFontName = gtk_editable_get_chars(GTK_EDITABLE(displayer_clist_config_font_entry), 0, -1);
 
 #	ifdef CODEDEBUG
 	DEBUG(("Ok\n"));
@@ -218,7 +234,7 @@ void displayer_clist_config_apply_clicked(GtkButton *button, gpointer user_data)
 	singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_clist_config));
 }
 
-void displayer_clist_config_ok_clicked(GtkButton *button, gpointer user_data)
+static void displayer_clist_config_ok_clicked(GtkButton *button, gpointer user_data)
 {
 	/* apply and save config */
 	displayer_clist_config_apply_clicked(NULL, NULL);
@@ -228,7 +244,7 @@ void displayer_clist_config_ok_clicked(GtkButton *button, gpointer user_data)
 	gtk_widget_destroy(displayer_clist_config_win);
 }
 
-void displayer_clist_config_cancel_clicked(GtkButton *button, gpointer user_data)
+static void displayer_clist_config_cancel_clicked(GtkButton *button, gpointer user_data)
 {
 	displayer_clist_config_cleanup();
 
@@ -236,7 +252,7 @@ void displayer_clist_config_cancel_clicked(GtkButton *button, gpointer user_data
 	gtk_widget_destroy(displayer_clist_config_win);
 }
 
-gint dlg_displayer_clist_config_delete_event( GtkWidget *widget, GdkEvent  *event, gpointer data )
+static gint dlg_displayer_clist_config_delete_event( GtkWidget *widget, GdkEvent  *event, gpointer data )
 {
 	displayer_clist_config_cleanup();
 
@@ -246,9 +262,30 @@ gint dlg_displayer_clist_config_delete_event( GtkWidget *widget, GdkEvent  *even
 	return (FALSE);
 }
 
-void displayer_clist_config_show()
+static void add_color_button(gchar *trans_label, gchar *color_str, gint col_arr_offset,
+	GtkWidget **col_hbox, GtkWidget **col_label, GtkWidget **col_button)
+{
+	GdkColor color;
+
+	gdk_color_parse(color_str, &color);
+	displayer_clist_config_status.color_array[col_arr_offset] = color.red;
+	displayer_clist_config_status.color_array[col_arr_offset + 1] = color.green;
+	displayer_clist_config_status.color_array[col_arr_offset + 2] = color.blue;
+
+	*col_hbox = gtk_hbox_new(FALSE, 5);
+	gtk_container_add(GTK_CONTAINER(displayer_clist_config_color_vbox), *col_hbox);
+	*col_label = gtk_label_new(trans_label);
+	gtk_box_pack_start(GTK_BOX(*col_hbox), *col_label, TRUE, TRUE, 0);
+	*col_button = color_button_new(trans_label, 60, 20,
+		&displayer_clist_config_status.color_array[col_arr_offset], 3);
+	gtk_box_pack_start(GTK_BOX(*col_hbox), *col_button, FALSE, TRUE, 0);
+	gtk_widget_show(*col_hbox);
+	gtk_widget_show(*col_label);
+	gtk_widget_show(*col_button);
+}
+
+void displayer_clist_config_show(void)
 {
-	GdkColor *color;
 	CListConfigData *ccd;
 
 #	ifdef CODEDEBUG
@@ -264,13 +301,13 @@ void displayer_clist_config_show()
 		displayer_clist_config = displayer_clist_config_new();
 		singit_config_gen_load(SINGIT_CONFIG_GEN(displayer_clist_config));
 	}
-	ccd = getDCC(displayer_clist_config);
+	ccd = GET_DCC(displayer_clist_config);
 	if (!ccd) {
 		singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_clist_config));
 		return;
 	}
 
-	displayer_clist_config_status.color_array = g_malloc(sizeof(guchar) * 9);
+	displayer_clist_config_status.color_array = g_malloc(sizeof(guchar) * 3 * 5);
 	displayer_clist_config_status.updating_displayer_list = FALSE;
 
 //	plugin_clist_tooltips = gtk_tooltips_new ();
@@ -283,7 +320,7 @@ void displayer_clist_config_show()
 	gtk_signal_connect(GTK_OBJECT(displayer_clist_config_win), "destroy",
 		       GTK_SIGNAL_FUNC(gtk_widget_destroyed), &displayer_clist_config_win);
 
-	gtk_window_set_title(GTK_WINDOW(displayer_clist_config_win), SINGIT_VERSION_STRING " Config");
+	gtk_window_set_title(GTK_WINDOW(displayer_clist_config_win), _("Navigation displayer config"));
 	gtk_window_set_policy(GTK_WINDOW(displayer_clist_config_win), FALSE, FALSE, FALSE);
 	gtk_container_border_width(GTK_CONTAINER(displayer_clist_config_win), 5);
 //	gtk_object_set_data (GTK_OBJECT(displayer_clist_config_win), "tooltips", plugin_clist_tooltips);
@@ -292,6 +329,20 @@ void displayer_clist_config_show()
 	gtk_container_add(GTK_CONTAINER(displayer_clist_config_win), displayer_clist_config_vbox);
 	gtk_widget_show(displayer_clist_config_vbox);
 
+	displayer_clist_config_force_globals_frame = gtk_frame_new("Force globals");
+	gtk_box_pack_start(GTK_BOX(displayer_clist_config_vbox), displayer_clist_config_force_globals_frame, FALSE, FALSE, 0);
+	gtk_widget_show(displayer_clist_config_force_globals_frame);
+
+	displayer_clist_config_force_globals_check_button = gtk_check_button_new_with_label(_("Force global settings"));
+	gtk_container_add(GTK_CONTAINER(displayer_clist_config_force_globals_frame), displayer_clist_config_force_globals_check_button);
+//	gtk_widget_set_sensitive(displayer_clist_config_force_globals_check_button, FALSE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(displayer_clist_config_force_globals_check_button),
+		ccd->forceGlobals);
+	gtk_signal_connect(GTK_OBJECT(displayer_clist_config_force_globals_check_button),
+		"toggled", GTK_SIGNAL_FUNC(displayer_clist_config_force_globals_toggle_event), NULL);
+	gtk_widget_show(displayer_clist_config_force_globals_check_button);
+
+
 	displayer_clist_config_notebook = gtk_notebook_new();
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(displayer_clist_config_notebook), GTK_POS_TOP);
 	gtk_box_pack_start(GTK_BOX(displayer_clist_config_vbox), displayer_clist_config_notebook, FALSE, FALSE, 0);
@@ -305,19 +356,6 @@ void displayer_clist_config_show()
 	gtk_widget_show(displayer_clist_config_displayer_label);
 	gtk_notebook_append_page(GTK_NOTEBOOK(displayer_clist_config_notebook), displayer_clist_config_displayer_vbox, displayer_clist_config_displayer_label);
 
-	displayer_clist_config_force_globals_frame = gtk_frame_new("Force globals");
-	gtk_box_pack_start(GTK_BOX(displayer_clist_config_displayer_vbox), displayer_clist_config_force_globals_frame, FALSE, FALSE, 0);
-	gtk_widget_show(displayer_clist_config_force_globals_frame);
-
-	displayer_clist_config_force_globals_check_button = gtk_check_button_new_with_label(_("Force global settings"));
-	gtk_container_add(GTK_CONTAINER(displayer_clist_config_force_globals_frame), displayer_clist_config_force_globals_check_button);
-	gtk_widget_set_sensitive(displayer_clist_config_force_globals_check_button, FALSE);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(displayer_clist_config_force_globals_check_button),
-		ccd->forceGlobals);
-	gtk_signal_connect(GTK_OBJECT(displayer_clist_config_force_globals_check_button),
-		"toggled", GTK_SIGNAL_FUNC(displayer_clist_config_force_globals_toggle_event), NULL);
-	gtk_widget_show(displayer_clist_config_force_globals_check_button);
-
 	/* font selection box (from XMMS) */
         displayer_clist_config_font_frame = gtk_frame_new(_("Lyrics font"));
         gtk_box_pack_start(GTK_BOX(displayer_clist_config_displayer_vbox), displayer_clist_config_font_frame, FALSE, FALSE, 2);
@@ -351,52 +389,30 @@ void displayer_clist_config_show()
 	gtk_container_set_border_width(GTK_CONTAINER(displayer_clist_config_color_vbox), 5);
 	gtk_widget_show(displayer_clist_config_color_vbox);
 
-	color = g_malloc(sizeof(GdkColor));
-	gdk_color_parse(ccd->activeColor, color);
-	displayer_clist_config_status.color_array[0] = color->red;
-	displayer_clist_config_status.color_array[1] = color->green;
-	displayer_clist_config_status.color_array[2] = color->blue;
+	add_color_button(_("Background Color"), ccd->backgroundColor, 0,
+		&displayer_clist_config_color_background_hbox_widget,
+		&displayer_clist_config_color_background_label,
+		&displayer_clist_config_color_background_button);
 
-	displayer_clist_config_color_active_hbox_widget = gtk_hbox_new(FALSE, 5);
-	gtk_container_add(GTK_CONTAINER(displayer_clist_config_color_vbox), displayer_clist_config_color_active_hbox_widget);
-	displayer_clist_config_color_active_label = gtk_label_new(_("Active Color"));
-	gtk_box_pack_start(GTK_BOX(displayer_clist_config_color_active_hbox_widget), displayer_clist_config_color_active_label, TRUE, TRUE, 0);
-	displayer_clist_config_color_active_button = color_button_new (NULL, 60, 20, &displayer_clist_config_status.color_array[0], 3);
-	gtk_box_pack_start(GTK_BOX(displayer_clist_config_color_active_hbox_widget), displayer_clist_config_color_active_button, FALSE, TRUE, 0);
-	gtk_widget_show(displayer_clist_config_color_active_hbox_widget);
-	gtk_widget_show(displayer_clist_config_color_active_label);
-	gtk_widget_show(displayer_clist_config_color_active_button);
+	add_color_button(_("Normal Text Color"), ccd->normalTextColor, 3,
+		&displayer_clist_config_color_normal_text_hbox_widget,
+		&displayer_clist_config_color_normal_text_label,
+		&displayer_clist_config_color_normal_text_button);
 
-	gdk_color_parse(ccd->backgroundColor, color);
-	displayer_clist_config_status.color_array[3] = color->red;
-	displayer_clist_config_status.color_array[4] = color->green;
-	displayer_clist_config_status.color_array[5] = color->blue;
+	add_color_button(_("Normal Bar Color"), ccd->normalBarColor, 6,
+		&displayer_clist_config_color_normal_bar_hbox_widget,
+		&displayer_clist_config_color_normal_bar_label,
+		&displayer_clist_config_color_normal_bar_button);
 
-	displayer_clist_config_color_background_hbox_widget = gtk_hbox_new(FALSE, 5);
-	gtk_container_add(GTK_CONTAINER(displayer_clist_config_color_vbox), displayer_clist_config_color_background_hbox_widget);
-	displayer_clist_config_color_background_label = gtk_label_new(_("Background Color"));
-	gtk_box_pack_start(GTK_BOX(displayer_clist_config_color_background_hbox_widget), displayer_clist_config_color_background_label, TRUE, TRUE, 0);
-	displayer_clist_config_color_background_button = color_button_new (NULL, 60, 20, &displayer_clist_config_status.color_array[3], 3);
-	gtk_box_pack_start(GTK_BOX(displayer_clist_config_color_background_hbox_widget), displayer_clist_config_color_background_button, FALSE, TRUE, 0);
-	gtk_widget_show(displayer_clist_config_color_background_hbox_widget);
-	gtk_widget_show(displayer_clist_config_color_background_label);
-	gtk_widget_show(displayer_clist_config_color_background_button);
+	add_color_button(_("Progress Text Color"), ccd->progressTextColor, 9,
+		&displayer_clist_config_color_progress_text_hbox_widget,
+		&displayer_clist_config_color_progress_text_label,
+		&displayer_clist_config_color_progress_text_button);
 
-	gdk_color_parse(ccd->textColor, color);
-	displayer_clist_config_status.color_array[6] = color->red;
-	displayer_clist_config_status.color_array[7] = color->green;
-	displayer_clist_config_status.color_array[8] = color->blue;
-	g_free(color);
-
-	displayer_clist_config_color_text_hbox_widget = gtk_hbox_new(FALSE, 5);
-	gtk_container_add(GTK_CONTAINER(displayer_clist_config_color_vbox), displayer_clist_config_color_text_hbox_widget);
-	displayer_clist_config_color_text_label = gtk_label_new(_("Text Color"));
-	gtk_box_pack_start(GTK_BOX(displayer_clist_config_color_text_hbox_widget), displayer_clist_config_color_text_label, TRUE, TRUE, 0);
-	displayer_clist_config_color_text_button = color_button_new (NULL, 60, 20, &displayer_clist_config_status.color_array[6], 3);
-	gtk_box_pack_start(GTK_BOX(displayer_clist_config_color_text_hbox_widget), displayer_clist_config_color_text_button, FALSE, TRUE, 0);
-	gtk_widget_show(displayer_clist_config_color_text_hbox_widget);
-	gtk_widget_show(displayer_clist_config_color_text_label);
-	gtk_widget_show(displayer_clist_config_color_text_button);
+	add_color_button(_("Progress Bar Color"), ccd->progressBarColor, 12,
+		&displayer_clist_config_color_progress_bar_hbox_widget,
+		&displayer_clist_config_color_progress_bar_label,
+		&displayer_clist_config_color_progress_bar_button);
 
 /*
 	lyrics displayer checkboxes config page
@@ -427,18 +443,6 @@ void displayer_clist_config_show()
 		ccd->hideIfNotFound);
 	gtk_widget_show(displayer_clist_config_hide_if_not_found_check_button);
 
-	displayer_clist_config_show_ball_check_button = gtk_check_button_new_with_label(_("Show the jumping ball"));
-	gtk_box_pack_start(GTK_BOX(displayer_clist_config_displayer_toggle_vbox), displayer_clist_config_show_ball_check_button, FALSE, FALSE, 0);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(displayer_clist_config_show_ball_check_button),
-		ccd->showJumpingBall);
-	gtk_widget_show(displayer_clist_config_show_ball_check_button);
-
-	displayer_clist_config_guess_sync_lyrics_check_button = gtk_check_button_new_with_label(_("Guess if we have synced lyrics and set ball"));
-	gtk_box_pack_start(GTK_BOX(displayer_clist_config_displayer_toggle_vbox), displayer_clist_config_guess_sync_lyrics_check_button, FALSE, FALSE, 0);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(displayer_clist_config_guess_sync_lyrics_check_button),
-		ccd->guessSyncLyrics);
-	gtk_widget_show(displayer_clist_config_guess_sync_lyrics_check_button);
-
 #	ifdef CODEDEBUG
 	displayer_clist_config_enable_debug_check_button = gtk_check_button_new_with_label(_("Enable console debug output"));
 	gtk_box_pack_start(GTK_BOX(displayer_clist_config_displayer_toggle_vbox), displayer_clist_config_enable_debug_check_button, FALSE, FALSE, 0);
@@ -501,7 +505,7 @@ void displayer_clist_config_show()
 	}
 }
 
-void displayer_clist_config_hide()
+void displayer_clist_config_hide(void)
 {
 #	ifdef CODEDEBUG
 	DEBUG(("dlg_singit_config.c [displayer_clist_config_hide]\n"));
