@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,16 +36,17 @@
 #include "singit_config.h"
 #include "singit_dialogs.h"
 #include "singit_displayer_plugin.h"
+#include "displayer_karaoke_window_status.h"
 #include "singit_wgt_karaoke.h"
 
 void displayer_karaoke_window_init(void);
 void displayer_karaoke_window_finish(void);
 
-void displayer_karaoke_window_show(void);
-void displayer_karaoke_window_hide(void);
-void displayer_karaoke_window_toggle(void);
+void displayer_karaoke_window_show(SingitSong *cur_song);
+void displayer_karaoke_window_hide(SingitSong *cur_song);
+void displayer_karaoke_window_toggle(SingitSong *cur_song);
 
-void displayer_karaoke_window_set_time(guint time, LSong *cur_song, GList *real_next);
+void displayer_karaoke_window_set_time(guint time, SingitSong *cur_song, GList *real_next);
 void displayer_karaoke_window_config_update(const SingitConfigData *singit_config);
 
 DisplayerPlugin karaoke_window_dp =
@@ -75,72 +76,36 @@ DisplayerPlugin karaoke_window_dp =
 	NULL
 };
 
-DisplayerPlugin *get_dplugin_info(void)
-{
-	karaoke_window_dp.description = g_strdup("Karaoke window displayer");
-	return &karaoke_window_dp;
-}
+DIPSPLAYER_SYMBOL(libdisplayer_karaoke_window, karaoke_window_dp)
 
 static GtkWidget *displayer_karaoke_window_win = NULL;
 static GtkWidget
 		*singit_vbox,
 			*singit_hbox,
 			*singit_timestamp_status_bar,
-			*singit_song_gtk_event_box, *singit_song_status_bar,
-			*displayer_karaoke_window_karaoke_widget;
+			*singit_song_gtk_event_box, *singit_song_status_bar;
+
 static GtkTooltips
 		*singit_tooltips;
 
 static gboolean displayer_karaoke_window_win_keypress(GtkWidget * w, GdkEventKey * event, gpointer data);
 
-// Changed by program - not restored
-typedef struct {
-
-	GdkColormap *winColorMap;
-	GdkColor     winPrivateColors[3];
-
-	guint timestamp_context_id;
-	guint song_context_id;
-	guint messageCounter;
-	gint jump_to_song;
-
-	gboolean canChangeVisibility;
-	gboolean isVisible;
-
-	gchar *fileName;
-	LSong *song;
-
-	gboolean print_debug;
-	gboolean toggle_yz;
-	gboolean guess_synced_lyrics;
-	gboolean show_jumping_ball;
-	gboolean hide_if_not_found;
-	gboolean auto_resize;
-
-}
-KaraokeWindowStatus;
-
-KaraokeWindowStatus karaoke_window_status;
-
-#define DEBUG(x)  { if (karaoke_window_status.print_debug) debug x; }
-#define PERROR(x) { if (karaoke_window_status.print_debug) perror(x); }
-
-void set_jumping_ball(void)
+static void set_jumping_ball(void)
 {
 	if (karaoke_window_status.guess_synced_lyrics) {
 		singit_karaoke_widget_set_jumping_ball(
-			SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget),
-			(l_song_guess_sync_lyrics(karaoke_window_status.song) &&
+			SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget),
+			(singit_song_guess_sync_lyrics(karaoke_window_status.song) &&
 			karaoke_window_status.show_jumping_ball));
 	}
 	else {
 		singit_karaoke_widget_set_jumping_ball(
-			SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget),
+			SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget),
 			karaoke_window_status.show_jumping_ball);
 	}
 }
 
-gboolean displayer_karaoke_window_change_visibility(gboolean visible, gboolean check)
+static gboolean displayer_karaoke_window_change_visibility(gboolean visible, gboolean check)
 {
 	static gboolean shouldBeVisible = TRUE;
 	if (!displayer_karaoke_window_win) { return FALSE; }
@@ -218,63 +183,74 @@ void displayer_karaoke_window_config_update(const SingitConfigData *singit_confi
 	karaoke_window_status.auto_resize = singit_config->autoResize;
 
 	singit_karaoke_widget_freeze
-		(SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget));
+		(SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget));
+
+	// Update colors (we don't care about the background)
 	singit_karaoke_widget_set_color(
-		SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget),
-		skwc_text, singit_config->textColor);
+		SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget),
+		skwc_normal_text, singit_config->normalTextColor);
 	singit_karaoke_widget_set_color(
-		SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget),
-		skwc_active, singit_config->activeColor);
+		SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget),
+		skwc_normal_bar, singit_config->normalBarColor);
 	singit_karaoke_widget_set_color(
-		SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget),
-		skwc_background, singit_config->backgroundColor);
+		SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget),
+		skwc_progress_text, singit_config->progressTextColor);
+	singit_karaoke_widget_set_color(
+		SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget),
+		skwc_progress_bar, singit_config->progressBarColor);
+
 	singit_karaoke_widget_set_font(
-		SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget),
+		SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget),
 		singit_config->lyricFontName);
+	singit_karaoke_widget_set_time_indicators(
+		SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget),
+		singit_config->showTimeIndicator);
 	set_jumping_ball();
 	singit_karaoke_widget_thaw
-		(SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget));
+		(SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget));
 }
 
-void displayer_karaoke_window_set_time(guint time, LSong *cur_song, GList *real_next)
+void displayer_karaoke_window_set_time(guint time, SingitSong *cur_song, GList *real_next)
 {
-	LSong *my_song = NULL;
+	SingitSong *my_song = NULL;
 	GList *item;
 
-	if (displayer_karaoke_window_win && GTK_WIDGET_VISIBLE(displayer_karaoke_window_win))
+	if (displayer_karaoke_window_win && GTK_WIDGET_VISIBLE(displayer_karaoke_window_win) &&
+		(gdk_window_is_visible(displayer_karaoke_window_win->window)) &&
+		(gdk_window_is_viewable(displayer_karaoke_window_win->window)))
 	{
-		my_song = l_song_attach(cur_song);
+		my_song = singit_song_attach(cur_song);
 		if (!my_song) { return; }
 
 		GDK_THREADS_ENTER();
 		if ((my_song != karaoke_window_status.song) ||
 			(strcmp(my_song->song_filename, karaoke_window_status.song->song_filename) != 0))
 		{
-			if (l_song_lyrics_found(my_song)) {
+			if (singit_song_lyrics_found(my_song)) {
 				set_status_filename(my_song->lyric_filename);
 			}
 			singit_karaoke_widget_freeze
-				(SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget));
+				(SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget));
 			singit_karaoke_widget_set_song
-				(SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget), my_song);
+				(SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget), my_song);
 			singit_karaoke_widget_set_time
-				(SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget), time);
+				(SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget), time);
 
-			l_song_detach(karaoke_window_status.song, TRUE);
+			singit_song_detach(&(karaoke_window_status.song));
 			karaoke_window_status.song = my_song;
 			set_jumping_ball();
 
 			singit_karaoke_widget_thaw
-				(SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget));
+				(SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget));
 		}
 		else {
 			singit_karaoke_widget_set_time
-				(SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget), time);
-			if (l_song_lyrics_found(my_song)) {
+				(SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget), time);
+			if (singit_song_lyrics_found(my_song)) {
 				item = (real_next) ? real_next : my_song->last_token;
 				if (item) { set_statusbar_messages(tTime(item) - time); }
-				l_song_detach(my_song, TRUE);
 			}
+			singit_song_detach(&my_song);
 		}
 		GDK_THREADS_LEAVE();
 	}
@@ -283,7 +259,7 @@ void displayer_karaoke_window_set_time(guint time, LSong *cur_song, GList *real_
 static gboolean displayer_karaoke_window_win_keypress(GtkWidget * w, GdkEventKey * event, gpointer data)
 {
 	gint volume, value;
-	LSong *cur_song = l_song_attach(karaoke_window_status.song);
+	SingitSong *cur_song = singit_song_attach(karaoke_window_status.song);
 
         switch(event->keyval) {
                 case GDK_Escape: // exit plugin
@@ -302,11 +278,9 @@ static gboolean displayer_karaoke_window_win_keypress(GtkWidget * w, GdkEventKey
 		case GDK_e:
 			if (event->state & GDK_CONTROL_MASK) { singit_editor_show(); }
 			break;
-#		ifdef HAVE_ID3
 		case GDK_i:
-			if (event->state & GDK_CONTROL_MASK) { singit_id3dlg_show(); }
+			if (event->state & GDK_CONTROL_MASK) { singit_tag_manager_show(); }
 			break;
-#		endif
 		case GDK_p:
 			if (event->state & GDK_CONTROL_MASK) { singit_config_show(); }
 			break;
@@ -382,8 +356,9 @@ static gboolean displayer_karaoke_window_win_keypress(GtkWidget * w, GdkEventKey
                         break;
         }
 
-	l_song_detach(cur_song, TRUE);
-        return TRUE;
+	singit_song_detach(&cur_song);
+
+	return TRUE;
 }
 
 void displayer_karaoke_window_finish(void)
@@ -400,52 +375,63 @@ void displayer_karaoke_window_finish(void)
 			singit_config_save_plugin_position("karaoke_window", posX, posY, -1, -1);
 		}
 		gtk_widget_destroy(displayer_karaoke_window_win);
-		karaoke_window_status.messageCounter = 0;
-		karaoke_window_status.timestamp_context_id = 0;
 	}
 
-	if (karaoke_window_status.fileName) {
-		g_free(karaoke_window_status.fileName);
-		karaoke_window_status.fileName = NULL;
-	}
-
-	l_song_detach(karaoke_window_status.song, TRUE);
+	displayer_karaoke_window_status_finish();
 }
 
-gint karaoke_window_delete_event( GtkWidget *widget, GdkEvent  *event, gpointer data )
+static gint karaoke_window_delete_event( GtkWidget *widget, GdkEvent  *event, gpointer data )
 {
 	karaoke_window_dp.disable(&karaoke_window_dp);
 	return (FALSE);
 }
 
-static void displayer_karaoke_window_build_dialog(void)
+void displayer_karaoke_window_init(void)
 {
 	gint posX, posY;
-	GtkWidget *tmp_win;
+
+	#ifdef CODEDEBUG
+	DEBUG(("displayer_karaoke_window.c [displayer_karaoke_window_init] : Start\n"));
+	#endif
+
+	g_return_if_fail(displayer_karaoke_window_win == NULL);
+
+	displayer_karaoke_window_status_init();
 
 	singit_tooltips = gtk_tooltips_new ();
 
-	tmp_win = gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_widget_realize(tmp_win);
-	gtk_window_set_title(GTK_WINDOW(tmp_win), SINGIT_VERSION_STRING);
-	gtk_window_set_policy(GTK_WINDOW(tmp_win), TRUE, FALSE, TRUE);
-	gtk_signal_connect(GTK_OBJECT(tmp_win), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &displayer_karaoke_window_win);
-	gtk_signal_connect(GTK_OBJECT(tmp_win), "delete_event", GTK_SIGNAL_FUNC(karaoke_window_delete_event), NULL);
-	gtk_signal_connect(GTK_OBJECT(tmp_win), "key-press-event", GTK_SIGNAL_FUNC(displayer_karaoke_window_win_keypress), NULL);
-	gtk_container_border_width(GTK_CONTAINER(tmp_win), 5);
-	gtk_object_set_data (GTK_OBJECT(tmp_win), "tooltips", singit_tooltips);
+	displayer_karaoke_window_win = gtk_window_new(GTK_WINDOW_DIALOG);
+	gtk_widget_realize(displayer_karaoke_window_win);
+	gtk_window_set_title(GTK_WINDOW(displayer_karaoke_window_win), SINGIT_VERSION_STRING);
+	gtk_window_set_policy(GTK_WINDOW(displayer_karaoke_window_win), TRUE, FALSE, TRUE);
+	gtk_signal_connect(GTK_OBJECT(displayer_karaoke_window_win),
+		"destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &displayer_karaoke_window_win);
+	gtk_signal_connect(GTK_OBJECT(displayer_karaoke_window_win),
+		"delete_event", GTK_SIGNAL_FUNC(karaoke_window_delete_event), NULL);
+	gtk_signal_connect(GTK_OBJECT(displayer_karaoke_window_win),
+		"key-press-event", GTK_SIGNAL_FUNC(displayer_karaoke_window_win_keypress), NULL);
+	gtk_container_border_width(GTK_CONTAINER(displayer_karaoke_window_win), 5);
+	gtk_object_set_data (GTK_OBJECT(displayer_karaoke_window_win),
+		"tooltips", singit_tooltips);
 
 	singit_vbox = gtk_vbox_new(FALSE, 5);
-	gtk_container_add(GTK_CONTAINER(tmp_win), singit_vbox);
+	gtk_container_add(GTK_CONTAINER(displayer_karaoke_window_win), singit_vbox);
 	gtk_widget_show(singit_vbox);
 
-	displayer_karaoke_window_karaoke_widget = singit_karaoke_widget_new();
-	gtk_box_pack_start(GTK_BOX(singit_vbox), displayer_karaoke_window_karaoke_widget, FALSE, FALSE, 0);
+	karaoke_window_status.karaoke_widget = singit_karaoke_widget_new();
+	gtk_box_pack_start(GTK_BOX(singit_vbox), karaoke_window_status.karaoke_widget, FALSE, FALSE, 0);
 	singit_karaoke_widget_set_show_empty_lines (
-		SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget), TRUE);
-	singit_karaoke_widget_set_lines (SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget), 5);
-	singit_karaoke_widget_set_toplines (SINGIT_KARAOKE_WIDGET(displayer_karaoke_window_karaoke_widget), 2);
-	gtk_widget_show(displayer_karaoke_window_karaoke_widget);
+		SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget), TRUE);
+	singit_karaoke_widget_set_lines (SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget), 5);
+	singit_karaoke_widget_set_toplines (SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget), 2);
+
+	// We want to stick to the style background color - anything else looks mad ;-)
+	singit_karaoke_widget_set_color_gdk(
+		SINGIT_KARAOKE_WIDGET(karaoke_window_status.karaoke_widget),
+		skwc_background, 
+		&(gtk_widget_get_style(karaoke_window_status.karaoke_widget)
+			->bg[GTK_STATE_NORMAL]));
+	gtk_widget_show(karaoke_window_status.karaoke_widget);
 
 	singit_hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(singit_vbox), singit_hbox, FALSE, FALSE, 1);
@@ -471,50 +457,34 @@ static void displayer_karaoke_window_build_dialog(void)
 		karaoke_window_status.timestamp_context_id, "         ");
 
 	if (singit_config_load_plugin_position("karaoke_window", &posX, &posY, NULL, NULL)) {
-		gtk_widget_set_uposition(tmp_win, posX, posY);
+		gtk_widget_set_uposition(displayer_karaoke_window_win, posX, posY);
 	}
 	else
 		gtk_window_set_position
-			(GTK_WINDOW(tmp_win), GTK_WIN_POS_CENTER);
-
-	displayer_karaoke_window_win = tmp_win;
+			(GTK_WINDOW(displayer_karaoke_window_win), GTK_WIN_POS_CENTER);
 }
 
-void displayer_karaoke_window_init(void)
-{
-	#ifdef CODEDEBUG
-	DEBUG(("displayer_karaoke_window.c [displayer_karaoke_window_init] : Start\n"));
-	#endif
-
-	karaoke_window_status.timestamp_context_id = 0;
-	karaoke_window_status.song_context_id = 0;
-	karaoke_window_status.messageCounter = 0;
-	karaoke_window_status.canChangeVisibility = TRUE;
-	karaoke_window_status.fileName = NULL;
-	karaoke_window_status.song = NULL;
-	karaoke_window_status.jump_to_song = 0;
-
-	displayer_karaoke_window_build_dialog();
-
-	#ifdef CODEDEBUG
-	DEBUG(("displayer_karaoke_window.c [displayer_karaoke_window_init] : Finish\n"));
-	#endif
-}
-
-void displayer_karaoke_window_show(void)
+void displayer_karaoke_window_show(SingitSong *cur_song)
 {
 	#ifdef CODEDEBUG
 	DEBUG(("displayer_karaoke_window.c [displayer_karaoke_window_show]\n"));
 	#endif
 
 	if (displayer_karaoke_window_win) {
-		if (!GTK_WIDGET_VISIBLE(displayer_karaoke_window_win))
-			{ gtk_widget_show(displayer_karaoke_window_win); }
-		else { gdk_window_raise(displayer_karaoke_window_win->window); }
+		if (singit_song_lyrics_found(cur_song)) {
+			if (!GTK_WIDGET_VISIBLE(displayer_karaoke_window_win))
+				{ gtk_widget_show(displayer_karaoke_window_win); }
+			else { gdk_window_raise(displayer_karaoke_window_win->window); }
+		}
+		else {
+			if (GTK_WIDGET_VISIBLE(displayer_karaoke_window_win)) {
+				gtk_widget_hide(displayer_karaoke_window_win);
+			}
+		}
 	}
 }
 
-void displayer_karaoke_window_hide(void)
+void displayer_karaoke_window_hide(SingitSong *cur_song)
 {
 	#ifdef CODEDEBUG
 	DEBUG(("displayer_karaoke_window.c [displayer_karaoke_window_hide]\n"));
@@ -527,7 +497,7 @@ void displayer_karaoke_window_hide(void)
 	}
 }
 
-void displayer_karaoke_window_toggle(void)
+void displayer_karaoke_window_toggle(SingitSong *cur_song)
 {
 	#ifdef CODEDEBUG
 	DEBUG(("displayer_karaoke_window.c [displayer_karaoke_window_toggle]\n"));
