@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,25 +37,27 @@ static CScene *scene = 0;
 extern "C" {
 #endif // __cplusplus
 
-void lyrics_draw(guint time, gboolean rotate)
+void opengl_lyrics_draw(guint time, gboolean rotate, gboolean beat, gfloat level[3])
 {
-	if (scene)
-		{ scene->draw(time, (rotate != FALSE) ? true : false); }
+	if (scene) {
+		scene->draw(time, (rotate == TRUE) ? true : false,
+			(beat == TRUE) ? true : false, level);
+	}
 }
 
-void lyrics_set_song(LSong *song)
+void opengl_lyrics_set_song(SingitSong *song)
 {
 	if (scene)
 		{ scene->set_song(song); }
 }
 
-void lyrics_free()
+void opengl_lyrics_free()
 {
 	delete scene;
 	scene = 0;
 }
 
-void lyrics_init()
+void opengl_lyrics_init()
 {
 	scene = new CScene;
 }
