@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,11 +28,10 @@
 extern "C" {
 #endif // __cplusplus
 
-void lyrics_init();
-void lyrics_draw(guint time, gboolean rotate);
-void lyrics_free();
-void lyrics_set_song(LSong *song);
-void lyrics_render_freq(gint16 data[2][256]);
+void opengl_lyrics_init();
+void opengl_lyrics_draw(guint time, gboolean rotate, gboolean beat, gfloat level[3]);
+void opengl_lyrics_free();
+void opengl_lyrics_set_song(SingitSong *song);
 
 #ifdef __cplusplus
 }
