@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <stdlib.h>
+#include <string.h>
 #include <stdio.h>
 
 #include <xmms/xmmsctrl.h>
@@ -36,23 +37,23 @@
 #include "gtkglarea.h"
 #include "c_wrapper.h"
 #include "singit_config.h"
-#include "dlg_opengl_config.h"
+
+#include "displayer_opengl_config.h"
+#include "displayer_opengl_config_dlg.h"
 
 #include "singit_dialogs.h"
 
-extern OpenGLConfig *opengl_config;
-
 void displayer_opengl_init(void);
 void displayer_opengl_finish(void);
 
-void displayer_opengl_show(void);
-void displayer_opengl_hide(void);
-void displayer_opengl_toggle(void);
-void displayer_opengl_render_freq(gint16 freq_data[2][256]);
-void displayer_opengl_render_pcm(gint16 pcm_data[2][512]);
+void displayer_opengl_show(SingitSong *cur_song);
+void displayer_opengl_hide(SingitSong *cur_song);
+void displayer_opengl_toggle(SingitSong *cur_song);
+void displayer_opengl_render_freq(gint16 freq_data[2][256], SingitSoundPrecalcs *ssp);
+void displayer_opengl_render_pcm(gint16 pcm_data[2][512], SingitSoundPrecalcs *ssp);
 void displayer_opengl_configure(void);
 
-void displayer_opengl_set_time(guint time, LSong *cur_song, GList *real_next);
+void displayer_opengl_set_time(guint time, SingitSong *cur_song, GList *real_next);
 void displayer_opengl_config_update(const SingitConfigData *singit_config);
 
 // static void displayer_opengl_limit_fps(gboolean init);
@@ -86,16 +87,10 @@ DisplayerPlugin opengl_dp =
 	displayer_opengl_render_freq
 };
 
-DisplayerPlugin *get_dplugin_info(void)
-{
-	opengl_dp.description = g_strdup("OpenGL displayer");
-	return &opengl_dp;
-}
+DIPSPLAYER_SYMBOL(libdisplayer_opengl, opengl_dp)
 
 static GtkWidget *displayer_opengl_window = NULL;
 
-OpenGLStatus displayer_opengl_status = { 0, 0, 0, 0, 0, 0, { { 0, 0} , { 0, 0 } }, FALSE, TRUE, 0 };
-
 gint16 static_pcm_data[2][512];
 gint16 static_freq_data[2][256];
 float madspin_data[256];
@@ -109,35 +104,53 @@ gint       glarea_reshape        (GtkWidget*, GdkEventConfigure*);
 gint       glarea_init           (GtkWidget*);
 gint       glarea_destroy        (GtkWidget*);
 
-gint displayer_opengl_delete_event( GtkWidget *widget, GdkEvent  *event, gpointer data )
+static gint displayer_opengl_delete_event( GtkWidget *widget, GdkEvent  *event, gpointer data )
 {
 	opengl_dp.disable(&opengl_dp);
 	return (FALSE);
 }
 
+static gint displayer_opengl_disable_func(gpointer data)
+{
+	GDK_THREADS_ENTER();
+	opengl_dp.disable(&opengl_dp);
+	GDK_THREADS_LEAVE();
+	return (FALSE);
+}
+
 void displayer_opengl_init(void)
 {
 	gchar *title;
 	GtkWidget* box_main;
 	gint posX, posY;
+	OpenGLConfigData *oglcd;
 
 	#ifdef CODEDEBUG
 	DEBUG(("displayer_opengl.c [displayer_opengl_init]\n"));
 	#endif
 
-	displayer_opengl_status.gl_area_widget = create_glarea();
-	if (displayer_opengl_status.gl_area_widget == NULL) {
-		opengl_dp.disable(&opengl_dp);
+	g_return_if_fail(displayer_opengl_window == NULL);
+
+	displayer_opengl_status_init();
+
+	if (!singit_config_gen_attach(displayer_opengl_config)) {
+		displayer_opengl_config = displayer_opengl_config_new();
+		singit_config_gen_load(SINGIT_CONFIG_GEN(displayer_opengl_config));
+	}
+
+	oglcd = GET_OGLCD(displayer_opengl_config);
+	if (!oglcd) {
+		singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_opengl_config));
 		return;
 	}
-	gtk_signal_connect(GTK_OBJECT(displayer_opengl_status.gl_area_widget), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &displayer_opengl_status.gl_area_widget);
 
-	if (!opengl_config_attach()) {
-		opengl_config_new();
-		opengl_config_load();
+	displayer_opengl_status.gl_area_widget = create_glarea();
+	if (displayer_opengl_status.gl_area_widget == NULL) {
+		gtk_idle_add (displayer_opengl_disable_func, NULL);
+		return;
 	}
-
-	displayer_opengl_status.song = NULL;
+	gtk_signal_connect(GTK_OBJECT(displayer_opengl_status.gl_area_widget),
+		"destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &displayer_opengl_status.gl_area_widget);
 
 	displayer_opengl_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_container_border_width(GTK_CONTAINER(displayer_opengl_window), 2);
@@ -170,35 +183,28 @@ void displayer_opengl_init(void)
 
 void displayer_opengl_finish(void)
 {
-	gint posX, posY;
+	OpenGLConfigData *oglcd;
 
 	#ifdef CODEDEBUG
 	DEBUG(("displayer_opengl.c [displayer_opengl_finish]\n"));
 	#endif
 
-	opengl_config_hide();
-
-	l_song_detach(displayer_opengl_status.song, TRUE);
-	displayer_opengl_status.song = NULL;
-
 	if (displayer_opengl_window) {
-		if (displayer_opengl_window->window) {
-			gdk_window_get_root_origin(displayer_opengl_window->window, &posX, &posY);
-			singit_config_save_plugin_position("opengl_window", posX, posY, -1, -1);
+		oglcd = GET_OGLCD(displayer_opengl_config);
+		if (displayer_opengl_window->window && (oglcd != NULL)) {
+			gdk_window_get_root_origin(displayer_opengl_window->window,
+				&oglcd->winPosX, &oglcd->winPosY);
+			singit_config_gen_save(SINGIT_CONFIG_GEN(displayer_opengl_config));
 		}
 		gtk_widget_destroy(displayer_opengl_window);
 	}
 
-	opengl_config_detach(TRUE);
+	singit_config_gen_detach(SINGIT_CONFIG_GEN(displayer_opengl_config));
 
-	gdk_gl_wait_gl();
-	gdk_gl_wait_gdk();
-	gdk_flush();
-
-	displayer_opengl_status.gl_area_widget = 0;
+	displayer_opengl_status_finish();
 }
 
-void displayer_opengl_show(void)
+void displayer_opengl_show(SingitSong *cur_song)
 {
 	#ifdef CODEDEBUG
 	DEBUG(("displayer_opengl.c [displayer_opengl_show]\n"));
@@ -211,7 +217,7 @@ void displayer_opengl_show(void)
 	}
 }
 
-void displayer_opengl_hide(void)
+void displayer_opengl_hide(SingitSong *cur_song)
 {
 	#ifdef CODEDEBUG
 	DEBUG(("displayer_opengl.c [displayer_opengl_hide]\n"));
@@ -223,7 +229,7 @@ void displayer_opengl_hide(void)
 	}
 }
 
-void displayer_opengl_toggle(void)
+void displayer_opengl_toggle(SingitSong *cur_song)
 {
 	#ifdef CODEDEBUG
 	DEBUG(("displayer_opengl.c [displayer_opengl_toggle]\n"));
@@ -237,25 +243,25 @@ void displayer_opengl_toggle(void)
 	}
 }
 
-void displayer_opengl_set_time(guint time, LSong *cur_song, GList *real_next)
+void displayer_opengl_set_time(guint time, SingitSong *cur_song, GList *real_next)
 {
-	LSong *my_song;
+	SingitSong *my_song;
 
-	if ((displayer_opengl_window) && (gdk_window_is_visible(displayer_opengl_window->window)))
+	if (displayer_opengl_window != NULL)
 	{
-		my_song = l_song_attach(cur_song);
+		my_song = singit_song_attach(cur_song);
 		if ((my_song != displayer_opengl_status.song) ||
 			(strcmp(my_song->song_filename, displayer_opengl_status.song->song_filename) != 0))
 		{
-			l_song_detach(displayer_opengl_status.song, TRUE);
-			displayer_opengl_status.song = l_song_attach(my_song);
-			displayer_opengl_status.rotate = !l_song_lyrics_found(my_song);
+			singit_song_detach(&displayer_opengl_status.song);
+			displayer_opengl_status.song = singit_song_attach(my_song);
+			displayer_opengl_status.rotate = !singit_song_lyrics_found(my_song);
 			GDK_THREADS_ENTER();
-			lyrics_set_song(my_song);
+			opengl_lyrics_set_song(my_song);
 			gtk_widget_queue_draw(displayer_opengl_status.gl_area_widget);
 			GDK_THREADS_LEAVE();
 		}
-		l_song_detach(my_song, TRUE);
+		singit_song_detach(&my_song);
 		displayer_opengl_status.time = time;
 	}
 }
@@ -275,33 +281,20 @@ void displayer_opengl_configure(void)
 	DEBUG(("displayer_opengl.c [displayer_opengl_configure]\n"));
 	#endif
 
-	opengl_config_show();
+	displayer_opengl_config_show();
 }
 
-void displayer_opengl_render_pcm(gint16 pcm_data[2][512])
+void displayer_opengl_render_pcm(gint16 pcm_data[2][512], SingitSoundPrecalcs *ssp)
 {
-	if (displayer_opengl_window) {
+	if (displayer_opengl_status.gl_area_widget != NULL) {
 		memcpy(static_pcm_data, pcm_data, 2 * 2 * 512);
-//		gtk_widget_queue_draw(displayer_opengl_status.gl_area_widget);
+		displayer_opengl_status.beat = ssp->beat;
+
+		gtk_widget_queue_draw(displayer_opengl_status.gl_area_widget);
 	}
 }
-/*
-static gdouble calc_level(gint16 freq_data[256])
-{
-	gint16 c = 0;
-        gdouble level = 0;
-        for(c = 0; c < 256; c++)
-        {
-                level = level + (gdouble) freq_data[c];
-        }
-        if(level > (512*256))
-        {
-                level = 512*256;
-        }
-	return (gdouble)(level / (512 * 256));
-}
-*/
-void displayer_opengl_render_freq(gint16 freq_data[2][256])
+
+void displayer_opengl_render_freq(gint16 freq_data[2][256], SingitSoundPrecalcs *ssp)
 {
 	gint i;
 	if (displayer_opengl_window) {
@@ -314,9 +307,13 @@ void displayer_opengl_render_freq(gint16 freq_data[2][256])
 			if (madspin_data[i] > 1.0)
 				madspin_data[i] = 1.0;
 		}
-	}
 
-//	g_print("levels - l: %f / r: %f\n", calc_level(freq_data[0]), calc_level(freq_data[1]));
+		displayer_opengl_status.level[0] = ssp->level[0];
+		displayer_opengl_status.level[1] = ssp->level[1];
+		displayer_opengl_status.level[2] = ssp->level[2];
+
+//		g_print("levels - l: %f / r: %f / c: %f\n", ssp->level[0], ssp->level[1], ssp->level[2]);
+	}
 
 /*
 	const gint scale[] =
@@ -357,11 +354,9 @@ static gboolean displayer_opengl_win_keypress(GtkWidget * w, GdkEventKey * event
 		case GDK_e:
 			if (event->state & GDK_CONTROL_MASK) { singit_editor_show(); }
 			break;
-#		ifdef HAVE_ID3
 		case GDK_i:
-			if (event->state & GDK_CONTROL_MASK) { singit_id3dlg_show(); }
+			if (event->state & GDK_CONTROL_MASK) { singit_tag_manager_show(); }
 			break;
-#		endif
 		case GDK_p:
 			if (event->state & GDK_CONTROL_MASK) { singit_config_show(); }
 			break;
@@ -503,7 +498,10 @@ gint glarea_draw (GtkWidget* widget, GdkEventExpose* event)
 
 	if (gtk_gl_area_make_current(GTK_GL_AREA(widget))) {
 
-		lyrics_draw(displayer_opengl_status.time, displayer_opengl_status.rotate);
+		opengl_lyrics_draw(displayer_opengl_status.time,
+			displayer_opengl_status.rotate,
+			displayer_opengl_status.beat,
+			displayer_opengl_status.level);
 		gtk_gl_area_swap_buffers(GTK_GL_AREA(widget));
 
 //		displayer_opengl_limit_fps(FALSE);
@@ -535,10 +533,10 @@ gint glarea_init (GtkWidget* widget)
 
 	if (gtk_gl_area_make_current (GTK_GL_AREA(widget))) {
 
-		const GLfloat light0_position[] = { 1.0, 1.0, 1.0, 0.0 };
-		const GLfloat light1_position[] = { 0.0, 1.0, 3.0, 0.0 };
+//		const GLfloat light0_position[] = { 1.0, 1.0, 1.0, 0.0 };
+//		const GLfloat light1_position[] = { 0.0, 1.0, 3.0, 0.0 };
 
-		lyrics_init();
+		opengl_lyrics_init();
 
 		glViewport(0, 0, (GLsizei)widget->allocation.width, (GLsizei)widget->allocation.height);
 
@@ -554,16 +552,16 @@ gint glarea_init (GtkWidget* widget)
 		glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 		glShadeModel(GL_FLAT);
 
-		glLightfv(GL_LIGHT0, GL_POSITION, light0_position);
-		glEnable(GL_LIGHT0);
+//		glLightfv(GL_LIGHT0, GL_POSITION, light0_position);
+//		glEnable(GL_LIGHT0);
 
-		glLightfv(GL_LIGHT1, GL_POSITION, light1_position);
-		glEnable(GL_LIGHT1);
+//		glLightfv(GL_LIGHT1, GL_POSITION, light1_position);
+//		glEnable(GL_LIGHT1);
 
 		glEnable(GL_DEPTH_TEST);
 		glDepthFunc(GL_LESS);
 
-		glEnable(GL_LIGHTING);
+//		glEnable(GL_LIGHTING);
 		glEnable(GL_BLEND);
 		glBlendFunc(GL_SRC_ALPHA,GL_ONE);
 		glColorMaterial(GL_FRONT, GL_AMBIENT_AND_DIFFUSE);
@@ -582,7 +580,7 @@ gint glarea_destroy (GtkWidget* widget)
 	#endif
 
 	glDeleteLists(displayer_opengl_status.display_list, 1);
-	lyrics_free();
+	opengl_lyrics_free();
 
 	return TRUE;
 }
@@ -594,22 +592,24 @@ gint glarea_destroy (GtkWidget* widget)
 
 gint glarea_button_release (GtkWidget* widget, GdkEventButton* event)
 {
+#	ifdef CODEDEBUG
 	int x = event->x;
 	int y = event->y;
+#	endif
 
 	if (event->button == 1) {
 		/* Mouse button 1 was released */
-		#ifdef CODEDEBUG
+#		ifdef CODEDEBUG
 		DEBUG(("displayer_opengl.c [glarea_button_release] - Button 1 release  (%d, %d)\n", x, y));
-		#endif
+#		endif
 		return TRUE;
 	}
 
 	if (event->button == 2) {
 		/* Mouse button 2 was released */
-		#ifdef CODEDEBUG
+#		ifdef CODEDEBUG
 		DEBUG(("displayer_opengl.c [glarea_button_release] - Button 2 release  (%d, %d)\n", x, y));
-		#endif
+#		endif
 		return TRUE;
 	}
 
@@ -618,22 +618,24 @@ gint glarea_button_release (GtkWidget* widget, GdkEventButton* event)
 
 gint glarea_button_press (GtkWidget* widget, GdkEventButton* event)
 {
+#	ifdef CODEDEBUG
 	int x = event->x;
 	int y = event->y;
+#	endif
 
 	if (event->button == 1) {
 		/* Mouse button 1 was engaged */
-		#ifdef CODEDEBUG
+#		ifdef CODEDEBUG
 		DEBUG(("displayer_opengl.c [glarea_button_release] - Button 1 press  (%d, %d)\n", x, y));
-		#endif
+#		endif
 		return TRUE;
 	}
 
 	if (event->button == 2) {
 		/* Mouse button 2 was engaged */
-		#ifdef CODEDEBUG
+#		ifdef CODEDEBUG
 		DEBUG(("displayer_opengl.c [glarea_button_release] - Button 2 press  (%d, %d)\n", x, y));
-		#endif
+#		endif
 		return TRUE;
 	}
 
@@ -699,4 +701,4 @@ static void displayer_opengl_limit_fps (gboolean init)
 		last_rtc_time = new_rtc_time;
 	}
 }
-*/
\ No newline at end of file
+*/
