@@ -1,6 +1,6 @@
 /*
  *  SingIt Lyrics Displayer
- *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
+ *  Copyright (C) 2000 - 2003 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,45 +21,8 @@
 #ifndef __DISPLAYER_OPENGL_H__
 #define __DISPLAYER_OPENGL_H__
 
-#include <gtk/gtk.h>
-
-#include <GL/gl.h>
-
-#include "singit_song.h"
 #include "singit_macros.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif // __cplusplus
-
-typedef struct _OpenGLStatus
-{
-	GtkWidget *gl_area_widget;
-
-	gint hide_mouse_id;
-	gint jump_to_song;
-	guint time;
-
-	gboolean toggle_yz;
-
-	LSong *song;
-
-	gint stereo_bass[2][2];
-
-	gboolean print_debug;
-	gboolean rotate;
-
-	guint display_list;
-}
-OpenGLStatus;
-
-#define DEBUG(x)  { if (displayer_opengl_status.print_debug) debug x; }
-#define PERROR(x) { if (displayer_opengl_status.print_debug) perror(x); }
-
-extern OpenGLStatus displayer_opengl_status;
-
-#ifdef __cplusplus
-}
-#endif // __cplusplus
+#include "displayer_opengl_status.h"
 
 #endif // __DISPLAYER_OPENGL_H__
