@@ -20,18 +20,22 @@
 
 #include <string.h>
 #include <stdio.h>
-#include <gtk/gtk.h>
+#include <gtk/gtkbin.h>
+#include <gtk/gtkclist.h>
+#include <gtk/gtkscrolledwindow.h>
 #include <gdk/gdkkeysyms.h>
 
 #include <xmms/plugin.h>
 #include <xmms/xmmsctrl.h>
 
-#include "singit_macros.h"
-#include "singit_macros_private.h"
+#include "singit_debug.h"
+#include "singit_config.h"
+
 #include "singit_song.h"
 #include "singit_song_private.h"
 #include "editor_singit_main.h"
 #include "editor_singit_private.h"
+#include "editor_config.h"
 
 #include "editor_clist_timestamps.h"
 
@@ -42,6 +46,8 @@ enum {
 
 extern EditorStatus editor_status;
 extern VisPlugin singit_vp;
+extern SingitConfigGen *editor_config;
+extern SingitConfigGen *singit_config;
 
 static GtkBinClass *parent_class = NULL;
 
@@ -113,7 +119,7 @@ GtkType editor_clist_timestamps_get_type (void)
 
 	if (!ect_type) {
 		GtkTypeInfo ect_info = {
-			"EditorClistTimestamps",
+			(gchar*) "EditorClistTimestamps",
 			sizeof (EditorClistTimestamps),
 			sizeof (EditorClistTimestampsClass),
 			(GtkClassInitFunc) editor_clist_timestamps_class_init,
@@ -145,9 +151,9 @@ static void editor_clist_timestamps_set_arg (GtkObject *object, GtkArg *arg, gui
 
 	editor = EDITOR_CLIST_TIMESTAMPS(object);
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_clist_timestamps.c [editor_clist_timestamps_set_arg]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [editor_clist_timestamps_set_arg]\n"));
+#endif
 
 	switch (arg_id) {
 	case ARG_CURSOR_TEXT_OFFSET:
@@ -164,9 +170,9 @@ static void editor_clist_timestamps_get_arg (GtkObject *object, GtkArg *arg, gui
 
 	editor = EDITOR_CLIST_TIMESTAMPS(object);
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_clist_timestamps.c [editor_clist_timestamps_get_arg]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [editor_clist_timestamps_get_arg]\n"));
+#endif
 
 	switch (arg_id) {
 	case ARG_CURSOR_TEXT_OFFSET:
@@ -284,20 +290,20 @@ gchar *editor_clist_timestamps_get_text(EditorClistTimestamps *ect, gint *char_o
 	gint chars = 0, cur_row = 1;
 	gchar *result = NULL, *temp, *concat_str;
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_clist_timestamps.c [editor_clist_timestamps_get_text]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [editor_clist_timestamps_get_text]\n"));
+#endif
 
 	g_return_val_if_fail (IS_EDITOR_CLIST_TIMESTAMPS(ect), NULL);
 
 	if (GTK_CLIST(ect->clist)->rows > 0) {
 		gtk_clist_get_text(GTK_CLIST(ect->clist), 0, 0, &concat_str);
 		result = g_strdup(concat_str);
-		if (cur_row < ect->active_line)
+		if (cur_row < (gint) ect->active_line)
 			{ chars = strlen(concat_str) + strlen("\n"); }
 		while (cur_row < GTK_CLIST(ect->clist)->rows) {
 			gtk_clist_get_text(GTK_CLIST(ect->clist), cur_row, 0, &concat_str);
-			if (cur_row < ect->active_line)
+			if (cur_row < (gint) ect->active_line)
 				{ chars += strlen(concat_str) + strlen("\n"); }
 			temp = result;
 			result = g_strconcat(temp, "\n", concat_str, NULL);
@@ -314,9 +320,9 @@ void editor_clist_timestamps_set_text(EditorClistTimestamps *ect, gchar *text, g
 	gchar **lines, *lbr[1][1];
 	gint i = 0, line = 0, chars = 0;
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_clist_timestamps.c [editor_clist_timestamps_set_text]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [editor_clist_timestamps_set_text]\n"));
+#endif
 
 	g_return_if_fail (IS_EDITOR_CLIST_TIMESTAMPS(ect));
 
@@ -340,21 +346,21 @@ void editor_clist_timestamps_set_text(EditorClistTimestamps *ect, gchar *text, g
 	ect->active_line = line;
 	gtk_clist_moveto(GTK_CLIST(ect->clist), line, 0, 0.5, 0);
 
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	if (!gtk_clist_row_is_visible(GTK_CLIST(ect->clist), line)) {
-		DEBUG(("Error: line %i not visible!\n", line), 9);
+		DEBUG(DLV_ALL, ("Error: line %i not visible!\n", line));
 	}
-#	endif
+#endif
 }
 
-gchar* get_time_token_string()
+static gchar* get_time_token_string()
 {
 	gint time;
 	gchar *time_stamp = g_new(gchar, 12);
 
 	time = xmms_remote_get_output_time(singit_vp.xmms_session);
-	if (time > getSCD(singit_config)->reactionTime) { time -= getSCD(singit_config)->reactionTime; }
-	if (editor_status.use_extended_timetags) {
+	if (time > GET_SCD->reactionTime) { time -= GET_SCD->reactionTime; }
+	if (GET_ECD(editor_config)->extendedLyrics) {
 		time_stamp[11] = '\0';
 		sprintf(time_stamp, "[%.2i:%.2i:%.3i]", time / 60000, time / 1000 % 60, time % 1000);
 	}
@@ -366,33 +372,8 @@ gchar* get_time_token_string()
 	return &time_stamp[0];
 }
 
-/*
-gtk_clist_get_selection_info    (GtkCList *clist,
-                                             gint x,
-                                             gint y,
-                                             gint *row,
-                                             gint *column);
-
-struct GdkEventButton
-{
-  GdkEventType type;
-  GdkWindow *window;
-  gint8 send_event;
-  guint32 time;
-  gdouble x;
-  gdouble y;
-  gdouble pressure;
-  gdouble xtilt;
-  gdouble ytilt;
-  guint state;
-  guint button;
-  GdkInputSource source;
-  guint32 deviceid;
-  gdouble x_root, y_root;
-};
-*/
-
-gchar *print_modifiers(gint state, gboolean compact)
+#ifdef CODEDEBUG
+static gchar *print_modifiers(gint state, gboolean compact)
 {
 	gchar *result = NULL;
 	if (compact == FALSE) {
@@ -435,44 +416,44 @@ gchar *print_modifiers(gint state, gboolean compact)
 	}
 	return result;
 }
+#endif
 
 static gboolean editor_clist_clicked_event(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
 {
 	gchar *oldline = NULL, *newline = NULL;
-#	ifdef CODEDEBUG
+#ifdef CODEDEBUG
 	gchar *modifiers;
-#	endif
+#endif
 	guint tag_type = 0;
 	gint str_len;
 	gchar *time_stamp;
 	gint row, column;
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_clist_timestamps.c [insert_remove_timestamp_event]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [insert_remove_timestamp_event]\n"));
+#endif
 
 	if (!event) { return TRUE; }
 
 	if (event->type != GDK_BUTTON_PRESS) // skip double and triple click events
 		{ return TRUE; }
 
-
 	if (!gtk_clist_get_selection_info(GTK_CLIST(widget), event->x, event->y, &row, &column))
 		{ return TRUE; }
 
 	gtk_clist_get_text(GTK_CLIST(widget), row, column, &oldline);
 	switch (event->button) {
 	case 1: // Left button
-#		ifdef CODEDEBUG
-		DEBUG_AREA(
+#ifdef CODEDEBUG
+		DEBUG_AREA(DLV_ALL,
 			debug("Left button\n");
 			modifiers = print_modifiers(event->state, TRUE);
 			debug(modifiers);
 			g_free(modifiers);
-		, 9)
-#		endif
+		);
+#endif
 		if (event->state & GDK_CONTROL_MASK) {
-			tag_type = l_song_get_timetag_type(oldline);
+			tag_type = singit_song_get_timetag_type(oldline);
 			switch (tag_type) {
 			case 1:
 				if (strlen(oldline) == 7) { newline = g_strdup("\0"); }
@@ -500,18 +481,18 @@ static gboolean editor_clist_clicked_event(GtkWidget *widget, GdkEventButton *ev
 		}
 		break;
 	case 3: // Right button
-#		ifdef CODEDEBUG
-		DEBUG_AREA(
+#ifdef CODEDEBUG
+		DEBUG_AREA(DLV_ALL,
 			debug("Right button\n");
 			modifiers = print_modifiers(event->state, TRUE);
 			debug(modifiers);
 			g_free(modifiers);
-		, 9)
-#		endif
+		);
+#endif
 		if (event->state & GDK_CONTROL_MASK) {
 			str_len = strlen(oldline);
 			if (str_len >= 7) {
-				if ((tag_type = l_song_get_timetag_type(&oldline[str_len - 7])) != 0) {
+				if ((tag_type = singit_song_get_timetag_type(&oldline[str_len - 7])) != 0) {
 					if (strlen(oldline) == 7) { newline = g_strdup("\0"); }
 					else {
 						oldline[str_len - 7] = '\0';
@@ -520,7 +501,7 @@ static gboolean editor_clist_clicked_event(GtkWidget *widget, GdkEventButton *ev
 					gtk_clist_set_text(GTK_CLIST(widget), row, column, newline);
 					return FALSE;
 				}
-				else if ((str_len >= 11) && ((tag_type = l_song_get_timetag_type(&oldline[str_len - 11])) != 0)) {
+				else if ((str_len >= 11) && ((tag_type = singit_song_get_timetag_type(&oldline[str_len - 11])) != 0)) {
 					if (strlen(oldline) == 11) { newline = g_strdup("\0"); }
 					else {
 						oldline[str_len - 11] = '\0';
@@ -545,6 +526,7 @@ static gboolean editor_clist_clicked_event(GtkWidget *widget, GdkEventButton *ev
 		}
 		break;
 	default:
+		break;
 	}
 	toggle_modified_state(TRUE);
 	return TRUE;
@@ -580,19 +562,20 @@ static gboolean editor_clist_timestamps_keypress(GtkWidget *widget, GdkEventKey
 			break;*/
 		default:
 			result = FALSE;
-			// DEBUG(("%x - %x\n", event->state, event->keyval), 9);
+			// DEBUG(DLV_ALL, ("%x - %x\n", event->state, event->keyval));
 			break;
         }
+
         return result;
 }
 
-GtkWidget* editor_clist_timestamps_new()
+GtkWidget* editor_clist_timestamps_new(void)
 {
 	GtkWidget *editor;
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_clist_timestamps.c [editor_clist_timestamps_new]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_clist_timestamps.c [editor_clist_timestamps_new]\n"));
+#endif
 
 	editor = gtk_type_new(TYPE_EDITOR_CLIST_TIMESTAMPS);
 
