@@ -18,6 +18,7 @@
  */
 
 
+#include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 #include <gtk/gtk.h>
@@ -27,11 +28,13 @@
 #include <xmms/plugin.h>
 #include <xmms/xmmsctrl.h>
 
-#include "singit_macros.h"
-#include "singit_macros_private.h"
+#include "singit_debug.h"
+#include "singit_config.h"
+
 #include "editor_singit_main.h"
 #include "editor_singit_private.h"
 #include "editor_synced_lyrics.h"
+#include "editor_config.h"
 
 enum {
 	ARG_0,
@@ -42,6 +45,8 @@ static GtkBinClass *parent_class = NULL;
 
 extern EditorStatus editor_status;
 extern VisPlugin singit_vp;
+extern SingitConfigGen *editor_config;
+extern SingitConfigGen *singit_config;
 
 static void editor_synced_lyrics_set_arg (GtkObject *object, GtkArg *arg, guint arg_id);
 static void editor_synced_lyrics_get_arg (GtkObject *object, GtkArg *arg, guint arg_id);
@@ -143,7 +148,7 @@ GtkType editor_synced_lyrics_get_type (void)
 
 	if (!ect_type) {
 		GtkTypeInfo ect_info = {
-			"EditorSyncedLyrics",
+			(gchar*) "EditorSyncedLyrics",
 			sizeof (EditorSyncedLyrics),
 			sizeof (EditorSyncedLyricsClass),
 			(GtkClassInitFunc) editor_synced_lyrics_class_init,
@@ -175,9 +180,9 @@ static void editor_synced_lyrics_set_arg (GtkObject *object, GtkArg *arg, guint
 
 	editor = EDITOR_SYNCED_LYRICS(object);
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_synced_lyrics.c [editor_synced_lyrics_set_arg]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_synced_lyrics.c [editor_synced_lyrics_set_arg]\n"));
+#endif
 
 	switch (arg_id) {
 	case ARG_CURSOR_TEXT_OFFSET:
@@ -194,9 +199,9 @@ static void editor_synced_lyrics_get_arg (GtkObject *object, GtkArg *arg, guint
 
 	editor = EDITOR_SYNCED_LYRICS(object);
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_synced_lyrics.c [editor_synced_lyrics_get_arg]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_synced_lyrics.c [editor_synced_lyrics_get_arg]\n"));
+#endif
 
 	switch (arg_id) {
 	case ARG_CURSOR_TEXT_OFFSET:
@@ -346,7 +351,7 @@ gboolean before_text_button_press_event (GtkWidget *widget, GdkEventButton *even
 	return TRUE;
 }
 
-gchar* find_next_break_start(gchar *text)
+static gchar* find_next_break_start(gchar *text)
 {
 	const gchar *breaker = "\n";
 	gchar *temp;
@@ -362,7 +367,7 @@ gchar* find_next_break_start(gchar *text)
 	}
 }
 
-gint find_end_pos(gchar *text, gboolean *is_breaker)
+static gint find_end_pos(gchar *text, gboolean *is_breaker)
 {
 	gchar *pos_copy;
 	const gchar *breaker = "\n";
@@ -420,8 +425,8 @@ gboolean after_text_button_press_event (GtkWidget *widget, GdkEventButton *event
 
 	switch (event->button) {
 	case 1: // Left mouse button
-		if (time > getSCD(singit_config)->reactionTime) { time -= getSCD(singit_config)->reactionTime; }
-		if (editor_status.use_extended_timetags) {
+		if (time > GET_SCD->reactionTime) { time -= GET_SCD->reactionTime; }
+		if (GET_ECD(editor_config)->extendedLyrics) {
 			time_stamp[11] = '\0';
 			sprintf(time_stamp, "[%.2i:%.2i:%.3i]", time / 60000, time / 1000 % 60, time % 1000);
 		}
@@ -538,9 +543,9 @@ gchar *editor_synced_lyrics_get_text(EditorSyncedLyrics *esl, gint *char_offset)
 {
 	gchar *result = NULL, *concat_str;
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_synced_lyrics.c [editor_synced_lyrics_get_text]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_synced_lyrics.c [editor_synced_lyrics_get_text]\n"));
+#endif
 
 	g_return_val_if_fail (IS_EDITOR_SYNCED_LYRICS(esl), NULL);
 
@@ -558,9 +563,9 @@ void editor_synced_lyrics_set_text(EditorSyncedLyrics *esl, gchar *text, gint ch
 	const gchar *breaker = "\n";
 	gchar *pos_insert;
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_synced_lyrics.c [editor_synced_lyrics_set_text]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_synced_lyrics.c [editor_synced_lyrics_set_text]\n"));
+#endif
 
 	g_return_if_fail (IS_EDITOR_SYNCED_LYRICS(esl));
 
@@ -584,7 +589,7 @@ void editor_synced_lyrics_set_text(EditorSyncedLyrics *esl, gchar *text, gint ch
 			char_offset = pos_insert - text + 1;
 		}
 		if (char_offset > 0) {
-			before_text_length = MIN(strlen(text), char_offset);
+			before_text_length = MIN((gint) strlen(text), char_offset);
 			gtk_text_insert(GTK_TEXT(esl->before_text), NULL,
 				&esl->before_text->style->black,
 				NULL, text, before_text_length);
@@ -616,13 +621,13 @@ void editor_synced_lyrics_set_text(EditorSyncedLyrics *esl, gchar *text, gint ch
 	gtk_text_thaw(GTK_TEXT(esl->before_text));
 }
 
-GtkWidget* editor_synced_lyrics_new()
+GtkWidget* editor_synced_lyrics_new(void)
 {
 	GtkWidget *editor;
 
-#	ifdef CODEDEBUG
-	DEBUG(("editor_synced_lyrics.c [editor_synced_lyrics_new]\n"), 9);
-#	endif
+#ifdef CODEDEBUG
+	DEBUG(DLV_ALL, ("editor_synced_lyrics.c [editor_synced_lyrics_new]\n"));
+#endif
 
 	editor = gtk_type_new(TYPE_EDITOR_SYNCED_LYRICS);
 	gtk_widget_set_usize(editor, 300, 160);
