@@ -29,12 +29,10 @@ extern "C" {
 
 void singit_editor_show();
 void singit_config_show();
+void singit_config_show_page(gint page);
 void singit_about_show();
-void singit_about_show_page(guint page);
-
-#ifdef HAVE_ID3
-void singit_id3dlg_show();
-#endif
+void singit_about_show_page(gint page);
+void singit_tag_manager_show();
 
 #ifdef __cplusplus
 }
