@@ -22,27 +22,11 @@
 #define __SINGIT_CONFIG_PRIVATE_H__
 
 /* creates new config data includes attachment */
-void singit_config_new();
-
-/* save config data */
-gboolean singit_config_save();
-/* load config data */
-gboolean singit_config_load();
+void singit_config_new(void);
 
 /* Just saves special data */
-gboolean singit_config_save_editor();
-gboolean singit_config_save_positions();
-gboolean singit_config_save_plugins();
-
-/* in use - control mechanism */
-/* if you use a config attach it, if none is attached config will be freed */
-/* this will prevent trouble with freeing the config */
-
-/* attach to the config file */
-/* result == attach succeed ? TRUE : FALSE */
-inline gboolean singit_config_attach();
-/* detach your config file - free it if there are no more attachments */
-/* result == freed ? TRUE : FALSE */
-void singit_config_detach();
+gboolean singit_config_save_editor(void);
+gboolean singit_config_save_positions(void);
+gboolean singit_config_save_plugins(void);
 
 #endif  // __SINGIT_CONFIG_PRIVATE_H__
